@@ -65,6 +65,8 @@ GsApp		*gs_app_row_get_app			(GsAppRow	*app_row);
 void		 gs_app_row_set_size_groups		(GsAppRow	*app_row,
 							 GtkSizeGroup	*image,
 							 GtkSizeGroup	*name);
+void		 gs_app_row_set_show_installed_size	(GsAppRow	*app_row,
+							 gboolean	 show_size);
 
 G_END_DECLS
 
