@@ -58,6 +58,7 @@ struct _GsApp
 {
 	GObject			 parent_instance;
 
+	GMutex			 mutex;
 	gchar			*id;
 	gchar			*unique_id;
 	gboolean		 unique_id_valid;
@@ -150,6 +151,18 @@ gs_app_kv_lpad (GString *str, const gchar *key, const gchar *value)
 	g_string_append_printf (str, " %s\n", value);
 }
 
+static void
+gs_app_kv_size (GString *str, const gchar *key, guint64 value)
+{
+	g_autofree gchar *tmp = NULL;
+	if (value == GS_APP_SIZE_UNKNOWABLE) {
+		gs_app_kv_lpad (str, key, "unknowable");
+		return;
+	}
+	tmp = g_format_size (value);
+	gs_app_kv_lpad (str, key, tmp);
+}
+
 G_GNUC_PRINTF (3, 4)
 static void
 gs_app_kv_printf (GString *str, const gchar *key, const gchar *fmt, ...)
@@ -183,6 +196,8 @@ _as_app_quirk_flag_to_string (AsAppQuirk quirk)
 		return "not-launchable";
 	if (quirk == AS_APP_QUIRK_NEEDS_USER_ACTION)
 		return "needs-user-action";
+	if (quirk == AS_APP_QUIRK_IS_PROXY)
+		return "is-proxy";
 	return NULL;
 }
 
@@ -225,6 +240,46 @@ _as_app_quirk_to_string (AsAppQuirk quirk)
 	return g_string_free (str, FALSE);
 }
 
+static gchar *
+gs_app_kudos_to_string (guint64 kudos)
+{
+	g_autoptr(GPtrArray) array = g_ptr_array_new ();
+	if ((kudos & GS_APP_KUDO_MY_LANGUAGE) > 0)
+		g_ptr_array_add (array, "my-language");
+	if ((kudos & GS_APP_KUDO_RECENT_RELEASE) > 0)
+		g_ptr_array_add (array, "recent-release");
+	if ((kudos & GS_APP_KUDO_FEATURED_RECOMMENDED) > 0)
+		g_ptr_array_add (array, "featured-recommended");
+	if ((kudos & GS_APP_KUDO_MODERN_TOOLKIT) > 0)
+		g_ptr_array_add (array, "modern-toolkit");
+	if ((kudos & GS_APP_KUDO_SEARCH_PROVIDER) > 0)
+		g_ptr_array_add (array, "search-provider");
+	if ((kudos & GS_APP_KUDO_INSTALLS_USER_DOCS) > 0)
+		g_ptr_array_add (array, "installs-user-docs");
+	if ((kudos & GS_APP_KUDO_USES_NOTIFICATIONS) > 0)
+		g_ptr_array_add (array, "uses-notifications");
+	if ((kudos & GS_APP_KUDO_USES_APP_MENU) > 0)
+		g_ptr_array_add (array, "uses-app-menu");
+	if ((kudos & GS_APP_KUDO_HAS_KEYWORDS) > 0)
+		g_ptr_array_add (array, "has-keywords");
+	if ((kudos & GS_APP_KUDO_HAS_SCREENSHOTS) > 0)
+		g_ptr_array_add (array, "has-screenshots");
+	if ((kudos & GS_APP_KUDO_POPULAR) > 0)
+		g_ptr_array_add (array, "popular");
+	if ((kudos & GS_APP_KUDO_PERFECT_SCREENSHOTS) > 0)
+		g_ptr_array_add (array, "perfect-screenshots");
+	if ((kudos & GS_APP_KUDO_HIGH_CONTRAST) > 0)
+		g_ptr_array_add (array, "high-contrast");
+	if ((kudos & GS_APP_KUDO_HI_DPI_ICON) > 0)
+		g_ptr_array_add (array, "hi-dpi-icon");
+	if ((kudos & GS_APP_KUDO_SANDBOXED) > 0)
+		g_ptr_array_add (array, "sandboxed");
+	if ((kudos & GS_APP_KUDO_SANDBOXED_SECURE) > 0)
+		g_ptr_array_add (array, "sandboxed-secure");
+	g_ptr_array_add (array, NULL);
+	return g_strjoinv ("|", (gchar **) array->pdata);
+}
+
 /**
  * gs_app_to_string:
  * @app: a #GsApp
@@ -270,38 +325,11 @@ gs_app_to_string (GsApp *app)
 		gs_app_kv_lpad (str, "bundle-kind",
 				as_bundle_kind_to_string (app->bundle_kind));
 	}
-	if ((app->kudos & GS_APP_KUDO_MY_LANGUAGE) > 0)
-		gs_app_kv_lpad (str, "kudo", "my-language");
-	if ((app->kudos & GS_APP_KUDO_RECENT_RELEASE) > 0)
-		gs_app_kv_lpad (str, "kudo", "recent-release");
-	if ((app->kudos & GS_APP_KUDO_FEATURED_RECOMMENDED) > 0)
-		gs_app_kv_lpad (str, "kudo", "featured-recommended");
-	if ((app->kudos & GS_APP_KUDO_MODERN_TOOLKIT) > 0)
-		gs_app_kv_lpad (str, "kudo", "modern-toolkit");
-	if ((app->kudos & GS_APP_KUDO_SEARCH_PROVIDER) > 0)
-		gs_app_kv_lpad (str, "kudo", "search-provider");
-	if ((app->kudos & GS_APP_KUDO_INSTALLS_USER_DOCS) > 0)
-		gs_app_kv_lpad (str, "kudo", "installs-user-docs");
-	if ((app->kudos & GS_APP_KUDO_USES_NOTIFICATIONS) > 0)
-		gs_app_kv_lpad (str, "kudo", "uses-notifications");
-	if ((app->kudos & GS_APP_KUDO_USES_APP_MENU) > 0)
-		gs_app_kv_lpad (str, "kudo", "uses-app-menu");
-	if ((app->kudos & GS_APP_KUDO_HAS_KEYWORDS) > 0)
-		gs_app_kv_lpad (str, "kudo", "has-keywords");
-	if ((app->kudos & GS_APP_KUDO_HAS_SCREENSHOTS) > 0)
-		gs_app_kv_lpad (str, "kudo", "has-screenshots");
-	if ((app->kudos & GS_APP_KUDO_POPULAR) > 0)
-		gs_app_kv_lpad (str, "kudo", "popular");
-	if ((app->kudos & GS_APP_KUDO_PERFECT_SCREENSHOTS) > 0)
-		gs_app_kv_lpad (str, "kudo", "perfect-screenshots");
-	if ((app->kudos & GS_APP_KUDO_HIGH_CONTRAST) > 0)
-		gs_app_kv_lpad (str, "kudo", "high-contrast");
-	if ((app->kudos & GS_APP_KUDO_HI_DPI_ICON) > 0)
-		gs_app_kv_lpad (str, "kudo", "hi-dpi-icon");
-	if ((app->kudos & GS_APP_KUDO_SANDBOXED) > 0)
-		gs_app_kv_lpad (str, "kudo", "sandboxed");
-	if ((app->kudos & GS_APP_KUDO_SANDBOXED_SECURE) > 0)
-		gs_app_kv_lpad (str, "kudo", "sandboxed-secure");
+	if (app->kudos > 0) {
+		g_autofree gchar *kudo_str = NULL;
+		kudo_str = gs_app_kudos_to_string (app->kudos);
+		gs_app_kv_lpad (str, "kudos", kudo_str);
+	}
 	gs_app_kv_printf (str, "kudo-percentage", "%u",
 			  gs_app_get_kudos_percentage (app));
 	if (app->name != NULL)
@@ -426,16 +454,10 @@ gs_app_to_string (GsApp *app)
 				  G_GUINT64_FORMAT "",
 				  app->install_date);
 	}
-	if (app->size_installed != 0) {
-		gs_app_kv_printf (str, "size-installed",
-				  "%" G_GUINT64_FORMAT "k",
-				  app->size_installed / 1024);
-	}
-	if (app->size_download != 0) {
-		gs_app_kv_printf (str, "size-download",
-				  "%" G_GUINT64_FORMAT "k",
-				  app->size_download / 1024);
-	}
+	if (app->size_installed != 0)
+		gs_app_kv_size (str, "size-installed", app->size_installed);
+	if (app->size_download != 0)
+		gs_app_kv_size (str, "size-download", app->size_download);
 	if (app->related->len > 0)
 		gs_app_kv_printf (str, "related", "%u", app->related->len);
 	if (app->history->len > 0)
@@ -536,6 +558,7 @@ gs_app_get_id (GsApp *app)
 void
 gs_app_set_id (GsApp *app, const gchar *id)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_free (app->id);
 	app->id = g_strdup (id);
@@ -766,7 +789,7 @@ gs_app_set_state_internal (GsApp *app, AsAppState state)
 	/* this state change was unexpected */
 	if (!state_change_ok) {
 		g_warning ("State change on %s from %s to %s is not OK",
-			   app->id,
+			   gs_app_get_unique_id (app),
 			   as_app_state_to_string (app->state),
 			   as_app_state_to_string (state));
 		return FALSE;
@@ -788,7 +811,8 @@ gs_app_set_state_internal (GsApp *app, AsAppState state)
 	default:
 		if (app->state_recover != state) {
 			g_debug ("%s non-transient state now %s",
-				 app->id, as_app_state_to_string (state));
+				 gs_app_get_unique_id (app),
+				 as_app_state_to_string (state));
 			app->state_recover = state;
 		}
 		break;
@@ -952,6 +976,7 @@ gs_app_set_kind (GsApp *app, AsAppKind kind)
 const gchar *
 gs_app_get_unique_id (GsApp *app)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_val_if_fail (GS_IS_APP (app), NULL);
 
 	/* invalid */
@@ -985,6 +1010,7 @@ gs_app_get_unique_id (GsApp *app)
 void
 gs_app_set_unique_id (GsApp *app, const gchar *unique_id)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 
 	/* check for sanity */
@@ -1026,6 +1052,7 @@ gs_app_get_name (GsApp *app)
 void
 gs_app_set_name (GsApp *app, GsAppQuality quality, const gchar *name)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 
 	/* only save this if the data is sufficiently high quality */
@@ -1066,6 +1093,7 @@ gs_app_get_branch (GsApp *app)
 void
 gs_app_set_branch (GsApp *app, const gchar *branch)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_free (app->branch);
 	app->branch = g_strdup (branch);
@@ -1151,6 +1179,7 @@ gs_app_get_sources (GsApp *app)
 void
 gs_app_set_sources (GsApp *app, GPtrArray *sources)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	if (app->sources != NULL)
 		g_ptr_array_unref (app->sources);
@@ -1204,6 +1233,7 @@ gs_app_get_source_ids (GsApp *app)
 void
 gs_app_clear_source_ids (GsApp *app)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_ptr_array_set_size (app->source_ids, 0);
 }
@@ -1221,6 +1251,7 @@ gs_app_clear_source_ids (GsApp *app)
 void
 gs_app_set_source_ids (GsApp *app, GPtrArray *source_ids)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	if (app->source_ids != NULL)
 		g_ptr_array_unref (app->source_ids);
@@ -1284,6 +1315,7 @@ gs_app_get_project_group (GsApp *app)
 void
 gs_app_set_project_group (GsApp *app, const gchar *project_group)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_free (app->project_group);
 	app->project_group = g_strdup (project_group);
@@ -1336,6 +1368,7 @@ gs_app_get_icons (GsApp *app)
 void
 gs_app_add_icon (GsApp *app, AsIcon *icon)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	if (icon == NULL) {
 		g_ptr_array_set_size (app->icons, 0);
@@ -1375,6 +1408,7 @@ gs_app_get_local_file (GsApp *app)
 void
 gs_app_set_local_file (GsApp *app, GFile *local_file)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_set_object (&app->local_file, local_file);
 }
@@ -1408,6 +1442,7 @@ gs_app_get_content_rating (GsApp *app)
 void
 gs_app_set_content_rating (GsApp *app, AsContentRating *content_rating)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_set_object (&app->content_rating, content_rating);
 }
@@ -1441,6 +1476,7 @@ gs_app_get_runtime (GsApp *app)
 void
 gs_app_set_runtime (GsApp *app, GsApp *runtime)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_set_object (&app->runtime, runtime);
 }
@@ -1457,6 +1493,7 @@ gs_app_set_runtime (GsApp *app, GsApp *runtime)
 void
 gs_app_set_pixbuf (GsApp *app, GdkPixbuf *pixbuf)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_set_object (&app->pixbuf, pixbuf);
 }
@@ -1616,6 +1653,7 @@ gs_app_get_version_ui (GsApp *app)
 void
 gs_app_set_version (GsApp *app, const gchar *version)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_free (app->version);
 	app->version = g_strdup (version);
@@ -1653,6 +1691,7 @@ gs_app_get_summary (GsApp *app)
 void
 gs_app_set_summary (GsApp *app, GsAppQuality quality, const gchar *summary)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 
 	/* only save this if the data is sufficiently high quality */
@@ -1694,6 +1733,7 @@ gs_app_get_description (GsApp *app)
 void
 gs_app_set_description (GsApp *app, GsAppQuality quality, const gchar *description)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 
 	/* only save this if the data is sufficiently high quality */
@@ -1736,6 +1776,7 @@ gs_app_get_url (GsApp *app, AsUrlKind kind)
 void
 gs_app_set_url (GsApp *app, AsUrlKind kind, const gchar *url)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_hash_table_insert (app->urls,
 			     g_strdup (as_url_kind_to_string (kind)),
@@ -1806,6 +1847,7 @@ gs_app_get_license_token_is_nonfree (const gchar *token)
 void
 gs_app_set_license (GsApp *app, GsAppQuality quality, const gchar *license)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	guint i;
 	g_auto(GStrv) tokens = NULL;
 
@@ -1866,6 +1908,7 @@ gs_app_get_summary_missing (GsApp *app)
 void
 gs_app_set_summary_missing (GsApp *app, const gchar *summary_missing)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_free (app->summary_missing);
 	app->summary_missing = g_strdup (summary_missing);
@@ -1903,6 +1946,7 @@ gs_app_get_menu_path (GsApp *app)
 void
 gs_app_set_menu_path (GsApp *app, gchar **menu_path)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_strfreev (app->menu_path);
 	app->menu_path = g_strdupv (menu_path);
@@ -1937,6 +1981,7 @@ gs_app_get_origin (GsApp *app)
 void
 gs_app_set_origin (GsApp *app, const gchar *origin)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	if (origin == app->origin)
 		return;
@@ -1987,6 +2032,7 @@ gs_app_get_origin_ui (GsApp *app)
 void
 gs_app_set_origin_ui (GsApp *app, const gchar *origin_ui)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	if (origin_ui == app->origin_ui)
 		return;
@@ -2029,6 +2075,7 @@ gs_app_get_origin_hostname (GsApp *app)
 void
 gs_app_set_origin_hostname (GsApp *app, const gchar *origin_hostname)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_autoptr(SoupURI) uri = NULL;
 	guint i;
 	const gchar *prefixes[] = { "download.", "mirrors.", NULL };
@@ -2149,6 +2196,7 @@ gs_app_set_update_version_internal (GsApp *app, const gchar *update_version)
 void
 gs_app_set_update_version (GsApp *app, const gchar *update_version)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	gs_app_set_update_version_internal (app, update_version);
 	gs_app_queue_notify (app, "version");
@@ -2183,6 +2231,7 @@ gs_app_get_update_details (GsApp *app)
 void
 gs_app_set_update_details (GsApp *app, const gchar *update_details)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_free (app->update_details);
 	app->update_details = g_strdup (update_details);
@@ -2260,6 +2309,7 @@ gs_app_get_management_plugin (GsApp *app)
 void
 gs_app_set_management_plugin (GsApp *app, const gchar *management_plugin)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 
 	/* plugins cannot adopt wildcard packages */
@@ -2352,6 +2402,7 @@ gs_app_get_review_ratings (GsApp *app)
 void
 gs_app_set_review_ratings (GsApp *app, GArray *review_ratings)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	if (app->review_ratings != NULL)
 		g_array_unref (app->review_ratings);
@@ -2575,6 +2626,7 @@ gs_app_get_metadata_item (GsApp *app, const gchar *key)
 void
 gs_app_set_metadata (GsApp *app, const gchar *key, const gchar *value)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	const gchar *found;
 	GString *str;
 
@@ -2633,6 +2685,7 @@ gs_app_add_addon (GsApp *app, GsApp *addon)
 {
 	gpointer found;
 	const gchar *id;
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 
 	g_return_if_fail (GS_IS_APP (app));
 	g_return_if_fail (GS_IS_APP (addon));
@@ -2646,6 +2699,25 @@ gs_app_add_addon (GsApp *app, GsApp *addon)
 	g_ptr_array_add (app->addons, g_object_ref (addon));
 }
 
+/**
+ * gs_app_remove_addon:
+ * @app: a #GsApp
+ * @addon: a #GsApp
+ *
+ * Removes an addon from the list of application addons.
+ *
+ * Since: 3.22
+ **/
+void
+gs_app_remove_addon (GsApp *app, GsApp *addon)
+{
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
+	g_return_if_fail (GS_IS_APP (app));
+	g_return_if_fail (GS_IS_APP (addon));
+	g_ptr_array_remove (app->addons, addon);
+	g_hash_table_remove (app->addons_hash, gs_app_get_id (addon));
+}
+
 /**
  * gs_app_get_related:
  * @app: a #GsApp
@@ -2677,6 +2749,7 @@ gs_app_add_related (GsApp *app, GsApp *app2)
 {
 	gchar *key;
 	gpointer found;
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 
 	g_return_if_fail (GS_IS_APP (app));
 
@@ -2729,6 +2802,7 @@ gs_app_get_history (GsApp *app)
 void
 gs_app_add_history (GsApp *app, GsApp *app2)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_ptr_array_add (app->history, g_object_ref (app2));
 }
@@ -2861,6 +2935,7 @@ gs_app_has_category (GsApp *app, const gchar *category)
 void
 gs_app_set_categories (GsApp *app, GPtrArray *categories)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_return_if_fail (categories != NULL);
 	if (app->categories != NULL)
@@ -2880,6 +2955,7 @@ gs_app_set_categories (GsApp *app, GPtrArray *categories)
 void
 gs_app_add_category (GsApp *app, const gchar *category)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_return_if_fail (category != NULL);
 	if (gs_app_has_category (app, category))
@@ -2887,6 +2963,36 @@ gs_app_add_category (GsApp *app, const gchar *category)
 	g_ptr_array_add (app->categories, g_strdup (category));
 }
 
+/**
+ * gs_app_remove_category:
+ * @app: a #GsApp
+ * @category: a category ID, e.g. "AudioVideo"
+ *
+ * Removes an category ID from an application, it exists.
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 3.24
+ **/
+gboolean
+gs_app_remove_category (GsApp *app, const gchar *category)
+{
+	const gchar *tmp;
+	guint i;
+
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
+	g_return_val_if_fail (GS_IS_APP (app), FALSE);
+
+	for (i = 0; i < app->categories->len; i++) {
+		tmp = g_ptr_array_index (app->categories, i);
+		if (g_strcmp0 (tmp, category) != 0)
+			continue;
+		g_ptr_array_remove_index_fast (app->categories, i);
+		return TRUE;
+	}
+	return FALSE;
+}
+
 /**
  * gs_app_get_key_colors:
  * @app: a #GsApp
@@ -2916,6 +3022,7 @@ gs_app_get_key_colors (GsApp *app)
 void
 gs_app_set_key_colors (GsApp *app, GPtrArray *key_colors)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_return_if_fail (key_colors != NULL);
 	if (app->key_colors != NULL)
@@ -2969,6 +3076,7 @@ gs_app_get_keywords (GsApp *app)
 void
 gs_app_set_keywords (GsApp *app, GPtrArray *keywords)
 {
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&app->mutex);
 	g_return_if_fail (GS_IS_APP (app));
 	g_return_if_fail (keywords != NULL);
 	if (app->keywords != NULL)
@@ -3372,6 +3480,7 @@ gs_app_finalize (GObject *object)
 {
 	GsApp *app = GS_APP (object);
 
+	g_mutex_clear (&app->mutex);
 	g_free (app->id);
 	g_free (app->unique_id);
 	g_free (app->branch);
@@ -3544,6 +3653,7 @@ gs_app_init (GsApp *app)
 	                                    g_str_equal,
 	                                    g_free,
 	                                    g_free);
+	g_mutex_init (&app->mutex);
 }
 
 /**
