@@ -97,6 +97,10 @@ typedef enum {
 	GS_APP_QUALITY_LAST
 } GsAppQuality;
 
+#if !AS_CHECK_VERSION(0,6,6)
+#define AS_APP_QUIRK_IS_PROXY			(1 << 9)
+#endif
+
 GsApp		*gs_app_new			(const gchar	*id);
 GsApp		*gs_app_new_from_unique_id	(const gchar	*unique_id);
 gchar		*gs_app_to_string		(GsApp		*app);
@@ -261,6 +265,8 @@ gboolean	 gs_app_has_category		(GsApp		*app,
 						 const gchar	*category);
 void		 gs_app_add_category		(GsApp		*app,
 						 const gchar	*category);
+gboolean	 gs_app_remove_category		(GsApp		*app,
+						 const gchar	*category);
 GPtrArray	*gs_app_get_keywords		(GsApp		*app);
 void		 gs_app_set_keywords		(GsApp		*app,
 						 GPtrArray	*keywords);
