@@ -32,10 +32,13 @@
 #include <libsoup/soup.h>
 
 #ifdef GDK_WINDOWING_X11
-#include <gtk/gtkx.h>
+#include <gdk/gdkx.h>
+#endif
+#ifdef GDK_WINDOWING_WAYLAND
+#if GTK_CHECK_VERSION(3,22,4)
+#include <gdk/gdkwayland.h>
+#endif
 #endif
-
-#include "gd-notification.h"
 
 #ifdef HAVE_PACKAGEKIT
 #include "gs-dbus-helper.h"
@@ -64,8 +67,6 @@ struct _GsApplication {
 	GsDbusHelper	*dbus_helper;
 #endif
 	GsShellSearchProvider *search_provider;
-	GNetworkMonitor *network_monitor;
-	gulong		 network_changed_handler;
 	GSettings       *settings;
 };
 
@@ -104,8 +105,13 @@ gs_application_init (GsApplication *application)
 		  _("Show application details (using application ID)"), _("ID") },
 		{ "details-pkg", '\0', 0, G_OPTION_ARG_STRING, NULL,
 		  _("Show application details (using package name)"), _("PKGNAME") },
+		{ "install", '\0', 0, G_OPTION_ARG_STRING, NULL,
+		  _("Install the application (using application ID)"), _("ID") },
 		{ "local-filename", '\0', 0, G_OPTION_ARG_FILENAME, NULL,
 		  _("Open a local package file"), _("FILENAME") },
+		{ "interaction", '\0', 0, G_OPTION_ARG_STRING, NULL,
+		  _("The kind of interaction expected for this action: either "
+		    "‘none’, ‘notify’, or ‘full’"), NULL },
 		{ "verbose", '\0', 0, G_OPTION_ARG_NONE, NULL,
 		  _("Show verbose debugging information"), NULL },
 		{ "profile", 0, 0, G_OPTION_ARG_NONE, NULL,
@@ -120,34 +126,6 @@ gs_application_init (GsApplication *application)
 	};
 
 	g_application_add_main_option_entries (G_APPLICATION (application), options);
-
-	application->network_changed_handler = 0;
-}
-
-static void
-network_changed_cb (GNetworkMonitor *monitor,
-		    gboolean available,
-		    GsApplication *app)
-{
-	gs_plugin_loader_set_network_status (app->plugin_loader, available);
-}
-
-static void
-gs_application_monitor_network (GsApplication *app)
-{
-	GNetworkMonitor *network_monitor;
-
-	network_monitor = g_network_monitor_get_default ();
-	if (network_monitor == NULL || app->network_changed_handler != 0)
-		return;
-	app->network_monitor = g_object_ref (network_monitor);
-
-	app->network_changed_handler = g_signal_connect (app->network_monitor, "network-changed",
-							 G_CALLBACK (network_changed_cb), app);
-
-	network_changed_cb (app->network_monitor,
-			    g_network_monitor_get_network_available (app->network_monitor),
-			    app);
 }
 
 static void
@@ -173,10 +151,13 @@ gs_application_initialize_plugins (GsApplication *app)
 		plugin_whitelist = g_strsplit (tmp, ",", -1);
 
 	app->plugin_loader = gs_plugin_loader_new ();
-	gs_plugin_loader_set_location (app->plugin_loader, NULL);
+	if (g_file_test (LOCALPLUGINDIR, G_FILE_TEST_EXISTS))
+		gs_plugin_loader_set_location (app->plugin_loader, LOCALPLUGINDIR);
 	if (!gs_plugin_loader_setup (app->plugin_loader,
 				     plugin_whitelist,
 				     plugin_blacklist,
+				     GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+				     NULL,
 				     &error)) {
 		g_warning ("Failed to setup plugins: %s", error->message);
 		exit (1);
@@ -255,9 +236,6 @@ gs_application_initialize_ui (GsApplication *app)
 
 	initialized = TRUE;
 
-	/* register ahead of loading the .ui file */
-	gd_notification_get_type ();
-
 	/* get CSS */
 	app->provider = gtk_css_provider_new ();
 	gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
@@ -280,13 +258,10 @@ gs_application_initialize_ui (GsApplication *app)
 
 	gs_shell_setup (app->shell, app->plugin_loader, app->cancellable);
 	gtk_application_add_window (GTK_APPLICATION (app), gs_shell_get_window (app->shell));
-
-	/* monitor the network as the many UI operations need the network */
-	gs_application_monitor_network (app);
 }
 
 static void
-initialize_ui_and_present_window (GsApplication *app)
+initialize_ui_and_present_window (GsApplication *app, const gchar *startup_id)
 {
 	GList *windows;
 	GtkWindow *window;
@@ -295,6 +270,9 @@ initialize_ui_and_present_window (GsApplication *app)
 	windows = gtk_application_get_windows (GTK_APPLICATION (app));
 	if (windows) {
 		window = windows->data;
+
+		if (startup_id != NULL)
+			gtk_window_set_startup_id (window, startup_id);
 		gtk_window_present (window);
 	}
 }
@@ -398,6 +376,7 @@ reboot_failed_cb (GObject *source, GAsyncResult *res, gpointer user_data)
 	gs_plugin_loader_app_action_async (app->plugin_loader,
 					   NULL, /* everything! */
 					   GS_PLUGIN_ACTION_UPDATE_CANCEL,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   app->cancellable,
 					   cancel_trigger_failed_cb,
 					   app);
@@ -473,6 +452,7 @@ reboot_and_install (GSimpleAction *action,
 	gs_application_initialize_plugins (app);
 	gs_plugin_loader_update_async (app->plugin_loader,
 				       NULL,
+				       GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 				       app->cancellable,
 				       (GAsyncReadyCallback) offline_update_cb,
 				       app);
@@ -510,7 +490,7 @@ set_mode_activated (GSimpleAction *action,
 	GsApplication *app = GS_APPLICATION (data);
 	const gchar *mode;
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, NULL);
 
 	mode = g_variant_get_string (parameter, NULL);
 	if (g_strcmp0 (mode, "updates") == 0) {
@@ -537,7 +517,7 @@ search_activated (GSimpleAction *action,
 	GsApplication *app = GS_APPLICATION (data);
 	const gchar *search;
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, NULL);
 
 	search = g_variant_get_string (parameter, NULL);
 	gs_shell_show_search (app->shell, search);
@@ -552,7 +532,7 @@ details_activated (GSimpleAction *action,
 	const gchar *id;
 	const gchar *search;
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, NULL);
 
 	g_variant_get (parameter, "(&s&s)", &id, &search);
 	if (search != NULL && search[0] != '\0')
@@ -577,13 +557,43 @@ details_pkg_activated (GSimpleAction *action,
 	GsApplication *app = GS_APPLICATION (data);
 	g_autoptr (GsApp) a = NULL;
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, NULL);
 
 	a = gs_app_new (NULL);
 	gs_app_add_source (a, g_variant_get_string (parameter, NULL));
 	gs_shell_show_app (app->shell, a);
 }
 
+static void
+install_activated (GSimpleAction *action,
+		   GVariant      *parameter,
+		   gpointer       data)
+{
+	GsApplication *app = GS_APPLICATION (data);
+	const gchar *id;
+	GsShellInteraction interaction;
+	g_autoptr (GsApp) a = NULL;
+
+	g_variant_get (parameter, "(&su)", &id, &interaction);
+	if (!as_utils_unique_id_valid (id)) {
+		g_warning ("Need to use a valid unique-id: %s", id);
+		return;
+	}
+
+	if (interaction == GS_SHELL_INTERACTION_FULL)
+		initialize_ui_and_present_window (app, NULL);
+	else
+		gs_application_initialize_ui (app);
+
+	a = gs_app_new_from_unique_id (id);
+	if (a == NULL) {
+		g_warning ("Could not create app from unique-id: %s", id);
+		return;
+	}
+
+	gs_shell_install (app->shell, a, interaction);
+}
+
 static void
 filename_activated (GSimpleAction *action,
 		    GVariant      *parameter,
@@ -630,7 +640,7 @@ show_offline_updates_error (GSimpleAction *action,
 {
 	GsApplication *app = GS_APPLICATION (data);
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, NULL);
 
 	gs_shell_set_mode (app->shell, GS_SHELL_MODE_UPDATES);
 	gs_update_monitor_show_error (app->update_monitor, app->shell);
@@ -642,26 +652,32 @@ install_resources_activated (GSimpleAction *action,
                              gpointer       data)
 {
 	GsApplication *app = GS_APPLICATION (data);
-#ifdef GDK_WINDOWING_X11
 	GdkDisplay *display;
-#endif
 	const gchar *mode;
 	const gchar *startup_id;
 	g_autofree gchar **resources = NULL;
 
 	g_variant_get (parameter, "(&s^a&s&s)", &mode, &resources, &startup_id);
 
-#ifdef GDK_WINDOWING_X11
 	display = gdk_display_get_default ();
-
+#ifdef GDK_WINDOWING_X11
 	if (GDK_IS_X11_DISPLAY (display)) {
 		if (startup_id != NULL && startup_id[0] != '\0')
 			gdk_x11_display_set_startup_notification_id (display,
 			                                             startup_id);
 	}
+#endif
+#ifdef GDK_WINDOWING_WAYLAND
+#if GTK_CHECK_VERSION(3,22,4)
+	if (GDK_IS_WAYLAND_DISPLAY (display)) {
+		if (startup_id != NULL && startup_id[0] != '\0')
+			gdk_wayland_display_set_startup_notification_id (display,
+			                                                 startup_id);
+	}
+#endif
 #endif
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, startup_id);
 
 	gs_shell_show_extras_search (app->shell, mode, resources);
 }
@@ -677,6 +693,7 @@ static GActionEntry actions[] = {
 	{ "search", search_activated, "s", NULL, NULL },
 	{ "details", details_activated, "(ss)", NULL, NULL },
 	{ "details-pkg", details_pkg_activated, "s", NULL, NULL },
+	{ "install", install_activated, "(su)", NULL, NULL },
 	{ "filename", filename_activated, "(s)", NULL, NULL },
 	{ "launch", launch_activated, "s", NULL, NULL },
 	{ "show-offline-update-error", show_offline_updates_error, NULL, NULL, NULL },
@@ -775,11 +792,6 @@ gs_application_dispose (GObject *object)
 	g_clear_object (&app->shell);
 	g_clear_object (&app->provider);
 	g_clear_object (&app->update_monitor);
-	if (app->network_changed_handler != 0) {
-		g_signal_handler_disconnect (app->network_monitor, app->network_changed_handler);
-		app->network_changed_handler = 0;
-	}
-	g_clear_object (&app->network_monitor);
 #ifdef HAVE_PACKAGEKIT
 	g_clear_object (&app->dbus_helper);
 #endif
@@ -788,6 +800,16 @@ gs_application_dispose (GObject *object)
 	G_OBJECT_CLASS (gs_application_parent_class)->dispose (object);
 }
 
+static GsShellInteraction
+get_page_interaction_from_string (const gchar *interaction)
+{
+	if (g_strcmp0 (interaction, "notify") == 0)
+		return GS_SHELL_INTERACTION_NOTIFY;
+	else if (g_strcmp0 (interaction, "none") == 0)
+		return GS_SHELL_INTERACTION_NONE;
+	return GS_SHELL_INTERACTION_FULL;
+}
+
 static int
 gs_application_handle_local_options (GApplication *app, GVariantDict *options)
 {
@@ -848,6 +870,19 @@ gs_application_handle_local_options (GApplication *app, GVariantDict *options)
 						"details-pkg",
 						g_variant_new_string (pkgname));
 		rc = 0;
+	} else if (g_variant_dict_lookup (options, "install", "&s", &id)) {
+		GsShellInteraction interaction = GS_SHELL_INTERACTION_FULL;
+		const gchar *str_interaction = NULL;
+
+		if (g_variant_dict_lookup (options, "interaction", "&s",
+					   &str_interaction))
+			interaction = get_page_interaction_from_string (str_interaction);
+
+		g_action_group_activate_action (G_ACTION_GROUP (app),
+						"install",
+						g_variant_new ("(su)", id,
+							       interaction));
+		rc = 0;
 	} else if (g_variant_dict_lookup (options, "local-filename", "^&ay", &local_filename)) {
 		g_action_group_activate_action (G_ACTION_GROUP (app),
 						"filename",
