@@ -268,7 +268,8 @@ main (int argc, char **argv)
 	profile = gs_plugin_loader_get_profile (plugin_loader);
 	ptask = as_profile_start_literal (profile, "GsCmd");
 	g_assert (ptask != NULL);
-	gs_plugin_loader_set_location (plugin_loader, "./plugins/.libs");
+	if (g_file_test (LOCALPLUGINDIR, G_FILE_TEST_EXISTS))
+		gs_plugin_loader_set_location (plugin_loader, LOCALPLUGINDIR);
 	if (plugin_whitelist_str != NULL)
 		plugin_whitelist = g_strsplit (plugin_whitelist_str, ",", -1);
 	if (plugin_blacklist_str != NULL)
@@ -276,6 +277,8 @@ main (int argc, char **argv)
 	ret = gs_plugin_loader_setup (plugin_loader,
 				      plugin_whitelist,
 				      plugin_blacklist,
+				      GS_PLUGIN_FAILURE_FLAGS_NONE,
+				      NULL,
 				      &error);
 	if (!ret) {
 		g_print ("Failed to setup plugins: %s\n", error->message);
@@ -290,6 +293,7 @@ main (int argc, char **argv)
 				g_object_unref (list);
 			list = gs_plugin_loader_get_installed (plugin_loader,
 							       refine_flags,
+							       GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 							       NULL,
 							       &error);
 			if (list == NULL) {
@@ -304,6 +308,7 @@ main (int argc, char **argv)
 			list = gs_plugin_loader_search (plugin_loader,
 							argv[2],
 							refine_flags,
+							GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 							NULL,
 							&error);
 			if (list == NULL) {
@@ -317,6 +322,7 @@ main (int argc, char **argv)
 		ret = gs_plugin_loader_app_action (plugin_loader,
 						   app,
 						   GS_PLUGIN_ACTION_UPGRADE_DOWNLOAD,
+						   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 						   NULL,
 						   &error);
 		if (ret)
@@ -327,11 +333,13 @@ main (int argc, char **argv)
 			ret = gs_plugin_loader_app_refine (plugin_loader,
 							   app,
 							   refine_flags,
+							   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 							   NULL,
 							   &error);
 			if (!ret)
 				break;
 		}
+		list = gs_app_list_new ();
 		gs_app_list_add (list, app);
 	} else if (argc == 3 && g_strcmp0 (argv[1], "launch") == 0) {
 		app = gs_app_new (argv[2]);
@@ -339,6 +347,7 @@ main (int argc, char **argv)
 			ret = gs_plugin_loader_app_action (plugin_loader,
 							   app,
 							   GS_PLUGIN_ACTION_LAUNCH,
+							   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 							   NULL,
 							   &error);
 			if (!ret)
@@ -349,6 +358,7 @@ main (int argc, char **argv)
 		app = gs_plugin_loader_file_to_app (plugin_loader,
 						    file,
 						    refine_flags,
+						    GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 						    NULL,
 						    &error);
 		if (app == NULL) {
@@ -363,6 +373,7 @@ main (int argc, char **argv)
 				g_object_unref (list);
 			list = gs_plugin_loader_get_updates (plugin_loader,
 							     refine_flags,
+							     GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 							     NULL,
 							     &error);
 			if (list == NULL) {
@@ -376,6 +387,7 @@ main (int argc, char **argv)
 				g_object_unref (list);
 			list = gs_plugin_loader_get_distro_upgrades (plugin_loader,
 								     refine_flags,
+								     GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 								     NULL,
 								     &error);
 			if (list == NULL) {
@@ -386,6 +398,7 @@ main (int argc, char **argv)
 	} else if (argc == 2 && g_strcmp0 (argv[1], "sources") == 0) {
 		list = gs_plugin_loader_get_sources (plugin_loader,
 						     refine_flags,
+						     GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 						     NULL,
 						     &error);
 		if (list == NULL)
@@ -396,6 +409,7 @@ main (int argc, char **argv)
 				g_object_unref (list);
 			list = gs_plugin_loader_get_popular (plugin_loader,
 							     refine_flags,
+							     GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 							     NULL,
 							     &error);
 			if (list == NULL) {
@@ -409,6 +423,7 @@ main (int argc, char **argv)
 				g_object_unref (list);
 			list = gs_plugin_loader_get_featured (plugin_loader,
 							      refine_flags,
+							      GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 							      NULL,
 							      &error);
 			if (list == NULL) {
@@ -422,6 +437,7 @@ main (int argc, char **argv)
 				g_ptr_array_unref (categories);
 			categories = gs_plugin_loader_get_categories (plugin_loader,
 								      refine_flags,
+								      GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 								      NULL,
 								      &error);
 			if (categories == NULL) {
@@ -447,6 +463,7 @@ main (int argc, char **argv)
 			list = gs_plugin_loader_get_category_apps (plugin_loader,
 								   category,
 								   refine_flags,
+								   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 								   NULL,
 								   &error);
 			if (list == NULL) {
@@ -458,7 +475,9 @@ main (int argc, char **argv)
 		GsPluginRefreshFlags refresh_flags;
 		refresh_flags = gs_cmd_refresh_flag_from_string (argv[2]);
 		ret = gs_plugin_loader_refresh (plugin_loader, cache_age,
-						refresh_flags, NULL, &error);
+						refresh_flags,
+						GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
+						NULL, &error);
 	} else {
 		ret = FALSE;
 		g_set_error_literal (&error,
