@@ -26,7 +26,7 @@
 GsApp *
 gs_plugin_loader_get_app_by_id (GsPluginLoader *plugin_loader,
 				const gchar *id,
-				GsPluginRefineFlags flags,
+				GsPluginRefineFlags refine_flags,
 				GCancellable *cancellable,
 				GError **error)
 {
@@ -34,7 +34,8 @@ gs_plugin_loader_get_app_by_id (GsPluginLoader *plugin_loader,
 	gboolean ret;
 
 	app = gs_app_new (id);
-	ret = gs_plugin_loader_app_refine (plugin_loader, app, flags,
+	ret = gs_plugin_loader_app_refine (plugin_loader, app, refine_flags,
+					   GS_PLUGIN_FAILURE_FLAGS_NONE,
 					   cancellable, error);
 	if (!ret)
 		g_clear_object (&app);
@@ -65,7 +66,8 @@ gs_plugin_loader_get_installed_finish_sync (GsPluginLoader *plugin_loader,
 
 GsAppList *
 gs_plugin_loader_get_installed (GsPluginLoader *plugin_loader,
-				GsPluginRefineFlags flags,
+				GsPluginRefineFlags refine_flags,
+				GsPluginFailureFlags failure_flags,
 				GCancellable *cancellable,
 				GError **error)
 {
@@ -80,7 +82,8 @@ gs_plugin_loader_get_installed (GsPluginLoader *plugin_loader,
 
 	/* run async method */
 	gs_plugin_loader_get_installed_async (plugin_loader,
-					      flags,
+					      refine_flags,
+					      failure_flags,
 					      cancellable,
 					      (GAsyncReadyCallback) gs_plugin_loader_get_installed_finish_sync,
 					      &helper);
@@ -108,7 +111,8 @@ gs_plugin_loader_search_finish_sync (GsPluginLoader *plugin_loader,
 GsAppList *
 gs_plugin_loader_search (GsPluginLoader *plugin_loader,
 			 const gchar *value,
-			 GsPluginRefineFlags flags,
+			 GsPluginRefineFlags refine_flags,
+			 GsPluginFailureFlags failure_flags,
 			 GCancellable *cancellable,
 			 GError **error)
 {
@@ -124,7 +128,8 @@ gs_plugin_loader_search (GsPluginLoader *plugin_loader,
 	/* run async method */
 	gs_plugin_loader_search_async (plugin_loader,
 				       value,
-				       flags,
+				       refine_flags,
+				       failure_flags,
 				       cancellable,
 				       (GAsyncReadyCallback) gs_plugin_loader_search_finish_sync,
 				       &helper);
@@ -151,7 +156,8 @@ gs_plugin_loader_get_updates_finish_sync (GsPluginLoader *plugin_loader,
 
 GsAppList *
 gs_plugin_loader_get_updates (GsPluginLoader *plugin_loader,
-			      GsPluginRefineFlags flags,
+			      GsPluginRefineFlags refine_flags,
+			      GsPluginFailureFlags failure_flags,
 			      GCancellable *cancellable,
 			      GError **error)
 {
@@ -166,7 +172,8 @@ gs_plugin_loader_get_updates (GsPluginLoader *plugin_loader,
 
 	/* run async method */
 	gs_plugin_loader_get_updates_async (plugin_loader,
-					    flags,
+					    refine_flags,
+					    failure_flags,
 					    cancellable,
 					    (GAsyncReadyCallback) gs_plugin_loader_get_updates_finish_sync,
 					    &helper);
@@ -193,9 +200,10 @@ gs_plugin_loader_get_distro_upgrades_finish_sync (GsPluginLoader *plugin_loader,
 
 GsAppList *
 gs_plugin_loader_get_distro_upgrades (GsPluginLoader *plugin_loader,
-			      GsPluginRefineFlags flags,
-			      GCancellable *cancellable,
-			      GError **error)
+				      GsPluginRefineFlags refine_flags,
+				      GsPluginFailureFlags failure_flags,
+				      GCancellable *cancellable,
+				      GError **error)
 {
 	GsPluginLoaderHelper helper;
 
@@ -208,7 +216,8 @@ gs_plugin_loader_get_distro_upgrades (GsPluginLoader *plugin_loader,
 
 	/* run async method */
 	gs_plugin_loader_get_distro_upgrades_async (plugin_loader,
-						    flags,
+						    refine_flags,
+						    failure_flags,
 						    cancellable,
 						    (GAsyncReadyCallback) gs_plugin_loader_get_distro_upgrades_finish_sync,
 						    &helper);
@@ -235,7 +244,8 @@ gs_plugin_loader_get_sources_finish_sync (GsPluginLoader *plugin_loader,
 
 GsAppList *
 gs_plugin_loader_get_sources (GsPluginLoader *plugin_loader,
-			      GsPluginRefineFlags flags,
+			      GsPluginRefineFlags refine_flags,
+			      GsPluginFailureFlags failure_flags,
 			      GCancellable *cancellable,
 			      GError **error)
 {
@@ -250,7 +260,8 @@ gs_plugin_loader_get_sources (GsPluginLoader *plugin_loader,
 
 	/* run async method */
 	gs_plugin_loader_get_sources_async (plugin_loader,
-					    flags,
+					    refine_flags,
+					    failure_flags,
 					    cancellable,
 					    (GAsyncReadyCallback) gs_plugin_loader_get_sources_finish_sync,
 					    &helper);
@@ -277,7 +288,8 @@ gs_plugin_loader_get_popular_finish_sync (GsPluginLoader *plugin_loader,
 
 GsAppList *
 gs_plugin_loader_get_popular (GsPluginLoader *plugin_loader,
-			      GsPluginRefineFlags flags,
+			      GsPluginRefineFlags refine_flags,
+			      GsPluginFailureFlags failure_flags,
 			      GCancellable *cancellable,
 			      GError **error)
 {
@@ -292,7 +304,8 @@ gs_plugin_loader_get_popular (GsPluginLoader *plugin_loader,
 
 	/* run async method */
 	gs_plugin_loader_get_popular_async (plugin_loader,
-					    flags,
+					    refine_flags,
+					    failure_flags,
 					    cancellable,
 					    (GAsyncReadyCallback) gs_plugin_loader_get_popular_finish_sync,
 					    &helper);
@@ -319,7 +332,8 @@ gs_plugin_loader_get_featured_finish_sync (GsPluginLoader *plugin_loader,
 
 GsAppList *
 gs_plugin_loader_get_featured (GsPluginLoader *plugin_loader,
-			       GsPluginRefineFlags flags,
+			       GsPluginRefineFlags refine_flags,
+			       GsPluginFailureFlags failure_flags,
 			       GCancellable *cancellable,
 			       GError **error)
 {
@@ -334,7 +348,8 @@ gs_plugin_loader_get_featured (GsPluginLoader *plugin_loader,
 
 	/* run async method */
 	gs_plugin_loader_get_featured_async (plugin_loader,
-					     flags,
+					     refine_flags,
+					     failure_flags,
 					     cancellable,
 					     (GAsyncReadyCallback) gs_plugin_loader_get_featured_finish_sync,
 					     &helper);
@@ -361,7 +376,8 @@ gs_plugin_loader_get_categories_finish_sync (GsPluginLoader *plugin_loader,
 
 GPtrArray *
 gs_plugin_loader_get_categories (GsPluginLoader *plugin_loader,
-				 GsPluginRefineFlags flags,
+				 GsPluginRefineFlags refine_flags,
+				 GsPluginFailureFlags failure_flags,
 				 GCancellable *cancellable,
 				 GError **error)
 {
@@ -376,7 +392,8 @@ gs_plugin_loader_get_categories (GsPluginLoader *plugin_loader,
 
 	/* run async method */
 	gs_plugin_loader_get_categories_async (plugin_loader,
-					       flags,
+					       refine_flags,
+					       failure_flags,
 					       cancellable,
 					       (GAsyncReadyCallback) gs_plugin_loader_get_categories_finish_sync,
 					       &helper);
@@ -404,7 +421,8 @@ gs_plugin_loader_get_category_apps_finish_sync (GsPluginLoader *plugin_loader,
 GsAppList *
 gs_plugin_loader_get_category_apps (GsPluginLoader *plugin_loader,
 				    GsCategory *category,
-				    GsPluginRefineFlags flags,
+				    GsPluginRefineFlags refine_flags,
+				    GsPluginFailureFlags failure_flags,
 				    GCancellable *cancellable,
 				    GError **error)
 {
@@ -420,7 +438,8 @@ gs_plugin_loader_get_category_apps (GsPluginLoader *plugin_loader,
 	/* run async method */
 	gs_plugin_loader_get_category_apps_async (plugin_loader,
 						  category,
-						  flags,
+						  refine_flags,
+						  failure_flags,
 						  cancellable,
 						  (GAsyncReadyCallback) gs_plugin_loader_get_category_apps_finish_sync,
 						  &helper);
@@ -448,7 +467,8 @@ gs_plugin_loader_app_refine_finish_sync (GsPluginLoader *plugin_loader,
 gboolean
 gs_plugin_loader_app_refine (GsPluginLoader *plugin_loader,
 			     GsApp *app,
-			     GsPluginRefineFlags flags,
+			     GsPluginRefineFlags refine_flags,
+			     GsPluginFailureFlags failure_flags,
 			     GCancellable *cancellable,
 			     GError **error)
 {
@@ -464,7 +484,8 @@ gs_plugin_loader_app_refine (GsPluginLoader *plugin_loader,
 	/* run async method */
 	gs_plugin_loader_app_refine_async (plugin_loader,
 					   app,
-					   flags,
+					   refine_flags,
+					   failure_flags,
 					   cancellable,
 					   (GAsyncReadyCallback) gs_plugin_loader_app_refine_finish_sync,
 					   &helper);
@@ -493,6 +514,7 @@ gboolean
 gs_plugin_loader_app_action (GsPluginLoader *plugin_loader,
 			     GsApp *app,
 			     GsPluginAction action,
+			     GsPluginFailureFlags failure_flags,
 			     GCancellable *cancellable,
 			     GError **error)
 {
@@ -509,6 +531,7 @@ gs_plugin_loader_app_action (GsPluginLoader *plugin_loader,
 	gs_plugin_loader_app_action_async (plugin_loader,
 					   app,
 					   action,
+					   failure_flags,
 					   cancellable,
 					   (GAsyncReadyCallback) gs_plugin_loader_app_action_finish_sync,
 					   &helper);
@@ -538,6 +561,7 @@ gs_plugin_loader_review_action (GsPluginLoader *plugin_loader,
 				GsApp *app,
 				AsReview *review,
 				GsPluginAction action,
+				GsPluginFailureFlags failure_flags,
 				GCancellable *cancellable,
 				GError **error)
 {
@@ -555,6 +579,7 @@ gs_plugin_loader_review_action (GsPluginLoader *plugin_loader,
 					      app,
 					      review,
 					      action,
+					      failure_flags,
 					      cancellable,
 					      (GAsyncReadyCallback) gs_plugin_loader_review_action_finish_sync,
 					      &helper);
@@ -583,6 +608,7 @@ gboolean
 gs_plugin_loader_auth_action (GsPluginLoader *plugin_loader,
 			      GsAuth *auth,
 			      GsPluginAction action,
+			      GsPluginFailureFlags failure_flags,
 			      GCancellable *cancellable,
 			      GError **error)
 {
@@ -599,6 +625,7 @@ gs_plugin_loader_auth_action (GsPluginLoader *plugin_loader,
 	gs_plugin_loader_auth_action_async (plugin_loader,
 					    auth,
 					    action,
+					    failure_flags,
 					    cancellable,
 					    (GAsyncReadyCallback) gs_plugin_loader_auth_action_finish_sync,
 					    &helper);
@@ -626,7 +653,8 @@ gs_plugin_loader_refresh_finish_sync (GsPluginLoader *plugin_loader,
 gboolean
 gs_plugin_loader_refresh (GsPluginLoader *plugin_loader,
 			  guint cache_age,
-			  GsPluginRefreshFlags flags,
+			  GsPluginRefreshFlags refresh_flags,
+			  GsPluginFailureFlags failure_flags,
 			  GCancellable *cancellable,
 			  GError **error)
 {
@@ -642,7 +670,8 @@ gs_plugin_loader_refresh (GsPluginLoader *plugin_loader,
 	/* run async method */
 	gs_plugin_loader_refresh_async (plugin_loader,
 					cache_age,
-					flags,
+					refresh_flags,
+					failure_flags,
 					cancellable,
 					(GAsyncReadyCallback) gs_plugin_loader_refresh_finish_sync,
 					&helper);
@@ -672,7 +701,8 @@ gs_plugin_loader_file_to_app_finish_sync (GObject *source_object,
 GsApp *
 gs_plugin_loader_file_to_app (GsPluginLoader *plugin_loader,
 			      GFile *file,
-			      GsPluginRefineFlags flags,
+			      GsPluginRefineFlags refine_flags,
+			      GsPluginFailureFlags failure_flags,
 			      GCancellable *cancellable,
 			      GError **error)
 {
@@ -689,7 +719,8 @@ gs_plugin_loader_file_to_app (GsPluginLoader *plugin_loader,
 	/* run async method */
 	gs_plugin_loader_file_to_app_async (plugin_loader,
 					    file,
-					    flags,
+					    refine_flags,
+					    failure_flags,
 					    cancellable,
 					    gs_plugin_loader_file_to_app_finish_sync,
 					    &helper);
