@@ -29,77 +29,92 @@
 G_BEGIN_DECLS
 
 GsAppList	*gs_plugin_loader_get_installed		(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GsAppList	*gs_plugin_loader_search		(GsPluginLoader	*plugin_loader,
 							 const gchar	*value,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GsAppList	*gs_plugin_loader_get_updates		(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GsAppList	*gs_plugin_loader_get_distro_upgrades	(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GsAppList	*gs_plugin_loader_get_sources		(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GsAppList	*gs_plugin_loader_get_popular		(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GsAppList	*gs_plugin_loader_get_featured		(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GPtrArray	*gs_plugin_loader_get_categories	(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GsAppList	*gs_plugin_loader_get_category_apps	(GsPluginLoader	*plugin_loader,
 							 GsCategory	*category,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 gboolean	 gs_plugin_loader_app_refine		(GsPluginLoader	*plugin_loader,
 							 GsApp		*app,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 gboolean	 gs_plugin_loader_app_action		(GsPluginLoader	*plugin_loader,
 							 GsApp		*app,
 							 GsPluginAction	 action,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 gboolean	 gs_plugin_loader_review_action		(GsPluginLoader	*plugin_loader,
 							 GsApp		*app,
 							 AsReview	*review,
 							 GsPluginAction	 action,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 gboolean	 gs_plugin_loader_auth_action		(GsPluginLoader	*plugin_loader,
 							 GsAuth		*auth,
 							 GsPluginAction	 action,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 gboolean	 gs_plugin_loader_refresh		(GsPluginLoader	*plugin_loader,
 							 guint		 cache_age,
-							 GsPluginRefreshFlags flags,
+							 GsPluginRefreshFlags refresh_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GsApp		*gs_plugin_loader_get_app_by_id		(GsPluginLoader	*plugin_loader,
 							 const gchar	*id,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GsApp		*gs_plugin_loader_file_to_app		(GsPluginLoader	*plugin_loader,
 							 GFile		*file,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
