@@ -53,7 +53,8 @@ typedef void	 (*GsPluginLoaderFinishedFunc)		(GsPluginLoader	*plugin_loader,
 
 GsPluginLoader	*gs_plugin_loader_new			(void);
 void		 gs_plugin_loader_get_installed_async	(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -61,7 +62,8 @@ GsAppList	*gs_plugin_loader_get_installed_finish	(GsPluginLoader	*plugin_loader,
 							 GAsyncResult	*res,
 							 GError		**error);
 void		 gs_plugin_loader_get_updates_async	(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -69,7 +71,8 @@ GsAppList	*gs_plugin_loader_get_updates_finish	(GsPluginLoader	*plugin_loader,
 							 GAsyncResult	*res,
 							 GError		**error);
 void		 gs_plugin_loader_get_distro_upgrades_async (GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -77,7 +80,8 @@ GsAppList	*gs_plugin_loader_get_distro_upgrades_finish (GsPluginLoader	*plugin_l
 							 GAsyncResult	*res,
 							 GError		**error);
 void		 gs_plugin_loader_get_unvoted_reviews_async (GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -85,7 +89,8 @@ GsAppList	*gs_plugin_loader_get_unvoted_reviews_finish (GsPluginLoader	*plugin_l
 							 GAsyncResult	*res,
 							 GError		**error);
 void		 gs_plugin_loader_get_sources_async	(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -93,7 +98,8 @@ GsAppList	*gs_plugin_loader_get_sources_finish	(GsPluginLoader	*plugin_loader,
 							 GAsyncResult	*res,
 							 GError		**error);
 void		 gs_plugin_loader_get_popular_async	(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -101,7 +107,8 @@ GsAppList	*gs_plugin_loader_get_popular_finish	(GsPluginLoader	*plugin_loader,
 							 GAsyncResult	*res,
 							 GError		**error);
 void		 gs_plugin_loader_get_featured_async	(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -109,7 +116,8 @@ GsAppList	*gs_plugin_loader_get_featured_finish	(GsPluginLoader	*plugin_loader,
 							 GAsyncResult	*res,
 							 GError		**error);
 void		 gs_plugin_loader_get_categories_async	(GsPluginLoader	*plugin_loader,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -118,7 +126,8 @@ GPtrArray	*gs_plugin_loader_get_categories_finish	(GsPluginLoader	*plugin_loader
 							 GError		**error);
 void		 gs_plugin_loader_get_category_apps_async (GsPluginLoader	*plugin_loader,
 							 GsCategory	*category,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -127,7 +136,8 @@ GsAppList	*gs_plugin_loader_get_category_apps_finish (GsPluginLoader	*plugin_loa
 							 GError		**error);
 void		 gs_plugin_loader_search_async		(GsPluginLoader	*plugin_loader,
 							 const gchar	*value,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -136,7 +146,8 @@ GsAppList	*gs_plugin_loader_search_finish		(GsPluginLoader	*plugin_loader,
 							 GError		**error);
 void		 gs_plugin_loader_search_files_async	(GsPluginLoader	*plugin_loader,
 							 const gchar	*value,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -145,7 +156,8 @@ GsAppList	*gs_plugin_loader_search_files_finish	(GsPluginLoader	*plugin_loader,
 							 GError		**error);
 void		 gs_plugin_loader_search_what_provides_async (GsPluginLoader	*plugin_loader,
 							 const gchar	*value,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -154,7 +166,8 @@ GsAppList	*gs_plugin_loader_search_what_provides_finish (GsPluginLoader	*plugin_
 							 GError		**error);
 void		 gs_plugin_loader_file_to_app_async	(GsPluginLoader	*plugin_loader,
 							 GFile		*file,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -163,6 +176,7 @@ GsApp		*gs_plugin_loader_file_to_app_finish	(GsPluginLoader	*plugin_loader,
 							 GError		**error);
 void		 gs_plugin_loader_update_async		(GsPluginLoader	*plugin_loader,
 							 GsAppList	*apps,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -172,6 +186,8 @@ gboolean	 gs_plugin_loader_update_finish		(GsPluginLoader	*plugin_loader,
 gboolean	 gs_plugin_loader_setup			(GsPluginLoader	*plugin_loader,
 							 gchar		**whitelist,
 							 gchar		**blacklist,
+							 GsPluginFailureFlags failure_flags,
+							 GCancellable	*cancellable,
 							 GError		**error);
 void		 gs_plugin_loader_dump_state		(GsPluginLoader	*plugin_loader);
 gboolean	 gs_plugin_loader_get_enabled		(GsPluginLoader	*plugin_loader,
@@ -185,7 +201,8 @@ void		 gs_plugin_loader_set_scale		(GsPluginLoader	*plugin_loader,
 							 guint		 scale);
 void		 gs_plugin_loader_app_refine_async	(GsPluginLoader	*plugin_loader,
 							 GsApp		*app,
-							 GsPluginRefineFlags flags,
+							 GsPluginRefineFlags refine_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -195,6 +212,7 @@ gboolean	 gs_plugin_loader_app_refine_finish	(GsPluginLoader	*plugin_loader,
 void		 gs_plugin_loader_app_action_async	(GsPluginLoader	*plugin_loader,
 							 GsApp		*app,
 							 GsPluginAction	 a,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -208,6 +226,7 @@ void		 gs_plugin_loader_review_action_async	(GsPluginLoader	*plugin_loader,
 							 GsApp		*app,
 							 AsReview	*review,
 							 GsPluginAction	 action,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -217,6 +236,7 @@ gboolean	 gs_plugin_loader_auth_action_finish	(GsPluginLoader	*plugin_loader,
 void		 gs_plugin_loader_auth_action_async	(GsPluginLoader	*plugin_loader,
 							 GsAuth		*auth,
 							 GsPluginAction	 action,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
@@ -225,14 +245,15 @@ gboolean	 gs_plugin_loader_refresh_finish	(GsPluginLoader	*plugin_loader,
 							 GError		**error);
 void		 gs_plugin_loader_refresh_async		(GsPluginLoader	*plugin_loader,
 							 guint		 cache_age,
-							 GsPluginRefreshFlags flags,
+							 GsPluginRefreshFlags refresh_flags,
+							 GsPluginFailureFlags failure_flags,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
 GsAppList	*gs_plugin_loader_get_pending		(GsPluginLoader	*plugin_loader);
 gboolean	 gs_plugin_loader_get_allow_updates	(GsPluginLoader	*plugin_loader);
-void		 gs_plugin_loader_set_network_status    (GsPluginLoader *plugin_loader,
-							 gboolean        online);
+gboolean	 gs_plugin_loader_get_network_available	(GsPluginLoader *plugin_loader);
+gboolean	 gs_plugin_loader_get_network_metered	(GsPluginLoader *plugin_loader);
 gboolean	 gs_plugin_loader_get_plugin_supported	(GsPluginLoader	*plugin_loader,
 							 const gchar	*plugin_func);
 
