@@ -66,6 +66,8 @@ typedef struct
 	SoupSession		*soup_session;
 	GsAppList		*global_cache;
 	GPtrArray		*rules[GS_PLUGIN_RULE_LAST];
+	GHashTable		*vfuncs;		/* string:pointer */
+	GMutex			 vfuncs_mutex;
 	gboolean		 enabled;
 	gchar			*locale;		/* allow-none */
 	gchar			*language;		/* allow-none */
@@ -143,21 +145,10 @@ gs_plugin_status_to_string (GsPluginStatus status)
 GsPlugin *
 gs_plugin_create (const gchar *filename, GError **error)
 {
-	GModule *module;
 	GsPlugin *plugin = NULL;
 	GsPluginPrivate *priv;
 	g_autofree gchar *basename = NULL;
 
-	module = g_module_open (filename, 0);
-	if (module == NULL) {
-		g_set_error (error,
-			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_FAILED,
-			     "failed to open plugin %s: %s",
-			     filename, g_module_error ());
-		return NULL;
-	}
-
 	/* get the plugin name from the basename */
 	basename = g_path_get_basename (filename);
 	if (!g_str_has_prefix (basename, "libgs_plugin_")) {
@@ -173,8 +164,16 @@ gs_plugin_create (const gchar *filename, GError **error)
 	/* create new plugin */
 	plugin = gs_plugin_new ();
 	priv = gs_plugin_get_instance_private (plugin);
-	priv->module = module;
 	priv->name = g_strdup (basename + 13);
+	priv->module = g_module_open (filename, 0);
+	if (priv->module == NULL) {
+		g_set_error (error,
+			     GS_PLUGIN_ERROR,
+			     GS_PLUGIN_ERROR_FAILED,
+			     "failed to open plugin %s: %s",
+			     filename, g_module_error ());
+		return NULL;
+	}
 	return plugin;
 }
 
@@ -203,8 +202,10 @@ gs_plugin_finalize (GObject *object)
 	if (priv->global_cache != NULL)
 		g_object_unref (priv->global_cache);
 	g_hash_table_unref (priv->cache);
+	g_hash_table_unref (priv->vfuncs);
 	g_mutex_clear (&priv->cache_mutex);
 	g_mutex_clear (&priv->timer_mutex);
+	g_mutex_clear (&priv->vfuncs_mutex);
 	if (priv->module != NULL)
 		g_module_close (priv->module);
 }
@@ -325,20 +326,36 @@ gs_plugin_action_stop (GsPlugin *plugin)
 }
 
 /**
- * gs_plugin_get_module:
+ * gs_plugin_get_symbol (skip):
  * @plugin: a #GsPlugin
  *
- * Gets the external module that backs the plugin.
+ * Gets the symbol from the module that backs the plugin. If the plugin is not
+ * enabled then no symbol is returned.
  *
- * Returns: the #GModule, or %NULL
+ * Returns: the pointer to the symbol, or %NULL
  *
  * Since: 3.22
  **/
-GModule *
-gs_plugin_get_module (GsPlugin *plugin)
+gpointer
+gs_plugin_get_symbol (GsPlugin *plugin, const gchar *function_name)
 {
 	GsPluginPrivate *priv = gs_plugin_get_instance_private (plugin);
-	return priv->module;
+	gpointer func = NULL;
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&priv->vfuncs_mutex);
+
+	/* disabled plugins shouldn't be checked */
+	if (!priv->enabled)
+		return NULL;
+
+	/* look up the symbol from the cache */
+	if (g_hash_table_lookup_extended (priv->vfuncs, function_name, NULL, &func))
+		return func;
+
+	/* look up the symbol using the elf headers */
+	g_module_symbol (priv->module, function_name, &func);
+	g_hash_table_insert (priv->vfuncs, g_strdup (function_name), func);
+
+	return func;
 }
 
 /**
@@ -1077,6 +1094,10 @@ gs_plugin_download_data (GsPlugin *plugin,
 	guint status_code;
 	g_autoptr(SoupMessage) msg = NULL;
 
+	g_return_val_if_fail (GS_IS_PLUGIN (plugin), NULL);
+	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
 	g_debug ("downloading %s from plugin %s", uri, priv->name);
 	msg = soup_message_new (SOUP_METHOD_GET, uri);
 	if (app != NULL) {
@@ -1135,6 +1156,11 @@ gs_plugin_download_file (GsPlugin *plugin,
 	g_autoptr(GError) error_local = NULL;
 	g_autoptr(SoupMessage) msg = NULL;
 
+	g_return_val_if_fail (GS_IS_PLUGIN (plugin), FALSE);
+	g_return_val_if_fail (uri != NULL, FALSE);
+	g_return_val_if_fail (filename != NULL, FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
 	g_debug ("downloading %s to %s from plugin %s", uri, filename, priv->name);
 	msg = soup_message_new (SOUP_METHOD_GET, uri);
 	if (app != NULL) {
@@ -1389,6 +1415,8 @@ gs_plugin_error_to_string (GsPluginError error)
 		return "invalid-format";
 	if (error == GS_PLUGIN_ERROR_DELETE_FAILED)
 		return "delete-failed";
+	if (error == GS_PLUGIN_ERROR_RESTART_REQUIRED)
+		return "restart-required";
 	return NULL;
 }
 
@@ -1576,8 +1604,11 @@ gs_plugin_init (GsPlugin *plugin)
 					     (GEqualFunc) as_utils_unique_id_equal,
 					     g_free,
 					     (GDestroyNotify) g_object_unref);
+	priv->vfuncs = g_hash_table_new_full (g_str_hash, g_str_equal,
+					      g_free, NULL);
 	g_mutex_init (&priv->cache_mutex);
 	g_mutex_init (&priv->timer_mutex);
+	g_mutex_init (&priv->vfuncs_mutex);
 	g_rw_lock_init (&priv->rwlock);
 }
 
