@@ -32,6 +32,7 @@ typedef struct
 	GtkListBoxRow	 parent_instance;
 
 	AsReview	*review;
+	gboolean	 network_available;
 	guint64		 actions;
 	GtkWidget	*stars;
 	GtkWidget	*summary_label;
@@ -88,8 +89,8 @@ gs_review_row_refresh (GsReviewRow *row)
 
 	/* set actions up */
 	if ((priv->actions & (1 << GS_PLUGIN_ACTION_REVIEW_UPVOTE |
-			      1 << GS_PLUGIN_ACTION_REVIEW_DOWNVOTE |
-			      1 << GS_PLUGIN_ACTION_REVIEW_DISMISS)) == 0) {
+			1 << GS_PLUGIN_ACTION_REVIEW_DOWNVOTE |
+			1 << GS_PLUGIN_ACTION_REVIEW_DISMISS)) == 0) {
 		gtk_widget_set_visible (priv->box_voting, FALSE);
 	} else {
 		gtk_widget_set_visible (priv->box_voting, TRUE);
@@ -104,6 +105,27 @@ gs_review_row_refresh (GsReviewRow *row)
 				priv->actions & 1 << GS_PLUGIN_ACTION_REVIEW_REMOVE);
 	gtk_widget_set_visible (priv->button_report,
 				priv->actions & 1 << GS_PLUGIN_ACTION_REVIEW_REPORT);
+
+	/* mark insensitive if no network */
+	if (priv->network_available) {
+		gtk_widget_set_sensitive (priv->button_yes, TRUE);
+		gtk_widget_set_sensitive (priv->button_no, TRUE);
+		gtk_widget_set_sensitive (priv->button_remove, TRUE);
+		gtk_widget_set_sensitive (priv->button_report, TRUE);
+	} else {
+		gtk_widget_set_sensitive (priv->button_yes, FALSE);
+		gtk_widget_set_sensitive (priv->button_no, FALSE);
+		gtk_widget_set_sensitive (priv->button_remove, FALSE);
+		gtk_widget_set_sensitive (priv->button_report, FALSE);
+	}
+}
+
+void
+gs_review_row_set_network_available (GsReviewRow *review_row, gboolean network_available)
+{
+	GsReviewRowPrivate *priv = gs_review_row_get_instance_private (review_row);
+	priv->network_available = network_available;
+	gs_review_row_refresh (review_row);
 }
 
 static gboolean
@@ -128,6 +150,8 @@ gs_review_row_notify_props_changed_cb (GsApp *app,
 static void
 gs_review_row_init (GsReviewRow *row)
 {
+	GsReviewRowPrivate *priv = gs_review_row_get_instance_private (row);
+	priv->network_available = TRUE;
 	gtk_widget_set_has_window (GTK_WIDGET (row), FALSE);
 	gtk_widget_init_template (GTK_WIDGET (row));
 }
