@@ -215,6 +215,15 @@ gs_plugin_func (void)
 	g_assert_cmpint (gs_app_list_length (list_remove), ==, 1);
 	g_object_unref (list_remove);
 
+	/* remove lazy-loaded app */
+	list_remove = gs_app_list_new ();
+	app = gs_app_new (NULL);
+	gs_app_list_add (list_remove, app);
+	gs_app_list_remove (list_remove, app);
+	g_assert_cmpint (gs_app_list_length (list_remove), ==, 0);
+	g_object_unref (app);
+	g_object_unref (list_remove);
+
 	/* respect priority when deduplicating */
 	list = gs_app_list_new ();
 	app = gs_app_new ("e");
@@ -304,6 +313,35 @@ gs_plugin_func (void)
 	g_object_unref (list);
 }
 
+static gpointer
+gs_app_thread_cb (gpointer data)
+{
+	GsApp *app = GS_APP (data);
+	for (guint i = 0; i < 10000; i++) {
+		g_assert_cmpstr (gs_app_get_unique_id (app), !=, NULL);
+		gs_app_set_branch (app, "master");
+		g_assert_cmpstr (gs_app_get_unique_id (app), !=, NULL);
+		gs_app_set_branch (app, "stable");
+	}
+	return NULL;
+}
+
+static void
+gs_app_thread_func (void)
+{
+	g_autoptr(GsApp) app = gs_app_new ("gimp.desktop");
+	g_autoptr(GThread) thread1 = NULL;
+	g_autoptr(GThread) thread2 = NULL;
+
+	/* try really hard to cause a threading problem */
+	g_setenv ("G_MESSAGES_DEBUG", "", TRUE);
+	thread1 = g_thread_new ("thread1", gs_app_thread_cb, app);
+	thread2 = g_thread_new ("thread2", gs_app_thread_cb, app);
+	g_thread_join (thread1);
+	g_thread_join (thread2);
+	g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
+}
+
 static void
 gs_app_unique_id_func (void)
 {
@@ -390,6 +428,7 @@ gs_plugin_loader_install_func (GsPluginLoader *plugin_loader)
 	gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
 	ret = gs_plugin_loader_app_action (plugin_loader, app,
 					   GS_PLUGIN_ACTION_INSTALL,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -400,6 +439,7 @@ gs_plugin_loader_install_func (GsPluginLoader *plugin_loader)
 	 * but dummy::refine() sets it */
 	ret = gs_plugin_loader_app_action (plugin_loader, app,
 					   GS_PLUGIN_ACTION_REMOVE,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -430,6 +470,7 @@ gs_plugin_loader_error_func (GsPluginLoader *plugin_loader)
 	gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
 	ret = gs_plugin_loader_app_action (plugin_loader, app,
 					   GS_PLUGIN_ACTION_UPDATE,
+					   GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -475,6 +516,7 @@ gs_plugin_loader_refine_func (GsPluginLoader *plugin_loader)
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_DESCRIPTION |
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENSE |
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_URL,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -498,6 +540,7 @@ gs_plugin_loader_key_colors_func (GsPluginLoader *plugin_loader)
 	app = gs_app_new ("zeus.desktop");
 	ret = gs_plugin_loader_app_refine (plugin_loader, app,
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_KEY_COLORS,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -528,14 +571,16 @@ gs_plugin_loader_updates_func (GsPluginLoader *plugin_loader)
 
 	/* get the updates list */
 	list = gs_plugin_loader_get_updates (plugin_loader,
-					     GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+					     GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON |
+					     GS_PLUGIN_REFINE_FLAGS_REQUIRE_UPDATE_DETAILS,
+					     GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					     NULL,
 					     &error);
 	g_assert_no_error (error);
 	g_assert (list != NULL);
 
 	/* make sure there are two entries */
-	g_assert_cmpint (gs_app_list_length (list), ==, 2);
+	g_assert_cmpint (gs_app_list_length (list), ==, 3);
 	app = gs_app_list_index (list, 0);
 	g_assert_cmpstr (gs_app_get_id (app), ==, "chiron.desktop");
 	g_assert_cmpint (gs_app_get_kind (app), ==, AS_APP_KIND_DESKTOP);
@@ -545,12 +590,19 @@ gs_plugin_loader_updates_func (GsPluginLoader *plugin_loader)
 
 	/* get the virtual non-apps OS update */
 	app = gs_app_list_index (list, 1);
-	g_assert_cmpstr (gs_app_get_id (app), ==, "os-update.virtual");
+	g_assert_cmpstr (gs_app_get_id (app), ==, "org.gnome.Software.OsUpdate");
 	g_assert_cmpstr (gs_app_get_name (app), ==, "OS Updates");
 	g_assert_cmpstr (gs_app_get_summary (app), ==, "Includes performance, stability and security improvements.");
 	g_assert_cmpint (gs_app_get_kind (app), ==, AS_APP_KIND_OS_UPDATE);
 	g_assert_cmpint (gs_app_get_state (app), ==, AS_APP_STATE_UPDATABLE);
 	g_assert_cmpint (gs_app_get_related(app)->len, ==, 2);
+
+	/* get the virtual non-apps OS update */
+	app = gs_app_list_index (list, 2);
+	g_assert_cmpstr (gs_app_get_id (app), ==, "proxy.desktop");
+	g_assert (gs_app_has_quirk (app, AS_APP_QUIRK_IS_PROXY));
+	g_assert_cmpint (gs_app_get_state (app), ==, AS_APP_STATE_UPDATABLE_LIVE);
+	g_assert_cmpint (gs_app_get_related(app)->len, ==, 2);
 }
 
 static void
@@ -564,6 +616,7 @@ gs_plugin_loader_distro_upgrades_func (GsPluginLoader *plugin_loader)
 	/* get the updates list */
 	list = gs_plugin_loader_get_distro_upgrades (plugin_loader,
 						     GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+						     GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 						     NULL,
 						     &error);
 	g_assert_no_error (error);
@@ -583,6 +636,7 @@ gs_plugin_loader_distro_upgrades_func (GsPluginLoader *plugin_loader)
 	ret = gs_plugin_loader_app_action (plugin_loader,
 					   app,
 					   GS_PLUGIN_ACTION_UPGRADE_DOWNLOAD,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -593,6 +647,7 @@ gs_plugin_loader_distro_upgrades_func (GsPluginLoader *plugin_loader)
 	ret = gs_plugin_loader_app_action (plugin_loader,
 					   app,
 					   GS_PLUGIN_ACTION_UPGRADE_TRIGGER,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -619,6 +674,7 @@ gs_plugin_loader_installed_func (GsPluginLoader *plugin_loader)
 					       GS_PLUGIN_REFINE_FLAGS_REQUIRE_MENU_PATH |
 					       GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON |
 					       GS_PLUGIN_REFINE_FLAGS_REQUIRE_PROVENANCE,
+					       GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					       NULL,
 					       &error);
 	g_assert_no_error (error);
@@ -677,6 +733,7 @@ gs_plugin_loader_search_func (GsPluginLoader *plugin_loader)
 	list = gs_plugin_loader_search (plugin_loader,
 					"spell",
 					GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
+					GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					NULL,
 					&error);
 	g_assert_no_error (error);
@@ -701,6 +758,7 @@ gs_plugin_loader_modalias_func (GsPluginLoader *plugin_loader)
 	list = gs_plugin_loader_search (plugin_loader,
 					"colorhug2",
 					GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
+					GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					NULL,
 					&error);
 	g_assert_no_error (error);
@@ -731,6 +789,7 @@ gs_plugin_loader_webapps_func (GsPluginLoader *plugin_loader)
 	gs_app_set_kind (app, AS_APP_KIND_WEB_APP);
 	ret = gs_plugin_loader_app_refine (plugin_loader, app,
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -758,6 +817,7 @@ gs_plugin_loader_dpkg_func (GsPluginLoader *plugin_loader)
 	app = gs_plugin_loader_file_to_app (plugin_loader,
 					    file,
 					    GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+					    GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					    NULL,
 					    &error);
 	g_assert_no_error (error);
@@ -793,6 +853,7 @@ gs_plugin_loader_packagekit_local_func (GsPluginLoader *plugin_loader)
 	app = gs_plugin_loader_file_to_app (plugin_loader,
 					    file,
 					    GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+					    GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					    NULL,
 					    &error);
 	g_assert_no_error (error);
@@ -827,6 +888,7 @@ gs_plugin_loader_fwupd_func (GsPluginLoader *plugin_loader)
 	app = gs_plugin_loader_file_to_app (plugin_loader,
 					    file,
 					    GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+					    GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					    NULL,
 					    &error);
 	g_assert_no_error (error);
@@ -863,6 +925,7 @@ gs_plugin_loader_repos_func (GsPluginLoader *plugin_loader)
 	gs_app_set_origin (app, "utopia");
 	ret = gs_plugin_loader_app_refine (plugin_loader, app,
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_ORIGIN_HOSTNAME,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -886,7 +949,7 @@ gs_plugin_loader_flatpak_repo_func (GsPluginLoader *plugin_loader)
 	g_autoptr(GsApp) app = NULL;
 
 	/* no flatpak, abort */
-	if (!gs_plugin_loader_get_enabled (plugin_loader, "flatpak-user"))
+	if (!gs_plugin_loader_get_enabled (plugin_loader, "flatpak"))
 		return;
 
 	/* load local file */
@@ -896,6 +959,7 @@ gs_plugin_loader_flatpak_repo_func (GsPluginLoader *plugin_loader)
 	app = gs_plugin_loader_file_to_app (plugin_loader,
 					    file,
 					    GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+					    GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					    NULL,
 					    &error);
 	g_assert_no_error (error);
@@ -903,7 +967,7 @@ gs_plugin_loader_flatpak_repo_func (GsPluginLoader *plugin_loader)
 	g_assert_cmpint (gs_app_get_kind (app), ==, AS_APP_KIND_SOURCE);
 	g_assert_cmpint (gs_app_get_state (app), ==, AS_APP_STATE_AVAILABLE);
 	g_assert_cmpstr (gs_app_get_id (app), ==, "example");
-	g_assert_cmpstr (gs_app_get_management_plugin (app), ==, "flatpak-user");
+	g_assert_cmpstr (gs_app_get_management_plugin (app), ==, "flatpak");
 	g_assert_cmpstr (gs_app_get_origin_hostname(app), ==, "foo.bar");
 	g_assert_cmpstr (gs_app_get_url (app, AS_URL_KIND_HOMEPAGE), ==, "http://foo.bar");
 	g_assert_cmpstr (gs_app_get_name (app), ==, "foo-bar");
@@ -916,6 +980,7 @@ gs_plugin_loader_flatpak_repo_func (GsPluginLoader *plugin_loader)
 	/* now install the remote */
 	ret = gs_plugin_loader_app_action (plugin_loader, app,
 					   GS_PLUGIN_ACTION_INSTALL,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -943,6 +1008,7 @@ gs_plugin_loader_flatpak_repo_func (GsPluginLoader *plugin_loader)
 	app2 = gs_plugin_loader_file_to_app (plugin_loader,
 					     file,
 					     GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+					     GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					     NULL,
 					     &error);
 	g_assert_no_error (error);
@@ -952,6 +1018,7 @@ gs_plugin_loader_flatpak_repo_func (GsPluginLoader *plugin_loader)
 	/* remove it */
 	ret = gs_plugin_loader_app_action (plugin_loader, app,
 					   GS_PLUGIN_ACTION_REMOVE,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -983,7 +1050,7 @@ gs_plugin_loader_flatpak_func (GsPluginLoader *plugin_loader)
 	g_autoptr(GsAppList) sources = NULL;
 
 	/* no flatpak, abort */
-	if (!gs_plugin_loader_get_enabled (plugin_loader, "flatpak-user"))
+	if (!gs_plugin_loader_get_enabled (plugin_loader, "flatpak"))
 		return;
 
 	/* no files to use */
@@ -1015,11 +1082,12 @@ gs_plugin_loader_flatpak_func (GsPluginLoader *plugin_loader)
 		return;
 	testdir_repourl = g_strdup_printf ("file://%s/repo", testdir);
 	gs_app_set_kind (app_source, AS_APP_KIND_SOURCE);
-	gs_app_set_management_plugin (app_source, "flatpak-user");
+	gs_app_set_management_plugin (app_source, "flatpak");
 	gs_app_set_state (app_source, AS_APP_STATE_AVAILABLE);
-	gs_app_set_url (app_source, AS_URL_KIND_HOMEPAGE, testdir_repourl);
+	gs_app_set_metadata (app_source, "flatpak::url", testdir_repourl);
 	ret = gs_plugin_loader_app_action (plugin_loader, app_source,
 					   GS_PLUGIN_ACTION_INSTALL,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -1037,6 +1105,7 @@ gs_plugin_loader_flatpak_func (GsPluginLoader *plugin_loader)
 	/* check the source now exists */
 	sources = gs_plugin_loader_get_sources (plugin_loader,
 						GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+						GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 						NULL,
 						&error);
 	g_assert_no_error (error);
@@ -1050,6 +1119,7 @@ gs_plugin_loader_flatpak_func (GsPluginLoader *plugin_loader)
 	ret = gs_plugin_loader_refresh (plugin_loader,
 					G_MAXUINT,
 					GS_PLUGIN_REFRESH_FLAGS_METADATA,
+					GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					NULL,
 					&error);
 	g_assert_no_error (error);
@@ -1061,6 +1131,7 @@ gs_plugin_loader_flatpak_func (GsPluginLoader *plugin_loader)
 					GS_PLUGIN_REFINE_FLAGS_REQUIRE_ORIGIN_HOSTNAME |
 					GS_PLUGIN_REFINE_FLAGS_REQUIRE_PERMISSIONS |
 					GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
+					GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					NULL,
 					&error);
 	g_assert_no_error (error);
@@ -1074,6 +1145,7 @@ gs_plugin_loader_flatpak_func (GsPluginLoader *plugin_loader)
 	g_assert_cmpint (gs_app_get_state (app), ==, AS_APP_STATE_AVAILABLE);
 	g_assert_cmpint ((gint64) gs_app_get_kudos (app), ==,
 			 GS_APP_KUDO_HAS_KEYWORDS |
+			 GS_APP_KUDO_HI_DPI_ICON |
 			 GS_APP_KUDO_SANDBOXED_SECURE |
 			 GS_APP_KUDO_SANDBOXED);
 	g_assert_cmpstr (gs_app_get_origin_hostname (app), ==, "");
@@ -1081,6 +1153,7 @@ gs_plugin_loader_flatpak_func (GsPluginLoader *plugin_loader)
 	/* install, also installing runtime */
 	ret = gs_plugin_loader_app_action (plugin_loader, app,
 					   GS_PLUGIN_ACTION_INSTALL,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -1128,6 +1201,7 @@ gs_plugin_loader_flatpak_func (GsPluginLoader *plugin_loader)
 	/* remove the application */
 	ret = gs_plugin_loader_app_action (plugin_loader, app,
 					   GS_PLUGIN_ACTION_REMOVE,
+					   GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -1149,6 +1223,7 @@ gs_plugin_loader_plugin_cache_func (GsPluginLoader *plugin_loader)
 	/* ensure we get the same results back from calling the methods twice */
 	list1 = gs_plugin_loader_get_distro_upgrades (plugin_loader,
 						      GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+						      GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 						      NULL,
 						      &error);
 	g_assert_no_error (error);
@@ -1158,6 +1233,7 @@ gs_plugin_loader_plugin_cache_func (GsPluginLoader *plugin_loader)
 
 	list2 = gs_plugin_loader_get_distro_upgrades (plugin_loader,
 						      GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+						      GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 						      NULL,
 						      &error);
 	g_assert_no_error (error);
@@ -1188,6 +1264,7 @@ gs_plugin_loader_authentication_func (GsPluginLoader *plugin_loader)
 	/* do an action that returns a URL */
 	ret = gs_plugin_loader_auth_action (plugin_loader, auth,
 					    GS_PLUGIN_ACTION_AUTH_REGISTER,
+					    GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					    NULL, &error);
 	g_assert_error (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_AUTH_INVALID);
 	g_assert (!ret);
@@ -1199,6 +1276,7 @@ gs_plugin_loader_authentication_func (GsPluginLoader *plugin_loader)
 	review = as_review_new ();
 	ret = gs_plugin_loader_review_action (plugin_loader, app, review,
 					      GS_PLUGIN_ACTION_REVIEW_REMOVE,
+					      GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					      NULL, &error);
 	g_assert_error (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_AUTH_REQUIRED);
 	g_assert (!ret);
@@ -1207,6 +1285,7 @@ gs_plugin_loader_authentication_func (GsPluginLoader *plugin_loader)
 	/* pretend to auth with no credentials */
 	ret = gs_plugin_loader_auth_action (plugin_loader, auth,
 					    GS_PLUGIN_ACTION_AUTH_LOGIN,
+					    GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					    NULL, &error);
 	g_assert_error (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_AUTH_INVALID);
 	g_assert (!ret);
@@ -1218,6 +1297,7 @@ gs_plugin_loader_authentication_func (GsPluginLoader *plugin_loader)
 	gs_auth_set_password (auth, "dummy");
 	ret = gs_plugin_loader_auth_action (plugin_loader, auth,
 					    GS_PLUGIN_ACTION_AUTH_LOGIN,
+					    GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					    NULL, &error);
 	g_assert_no_error (error);
 	g_assert (ret);
@@ -1227,6 +1307,7 @@ gs_plugin_loader_authentication_func (GsPluginLoader *plugin_loader)
 	review2 = as_review_new ();
 	ret = gs_plugin_loader_review_action (plugin_loader, app, review2,
 					      GS_PLUGIN_ACTION_REVIEW_REMOVE,
+					      GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					      NULL, &error);
 	g_assert_no_error (error);
 	g_assert (ret);
@@ -1279,6 +1360,7 @@ gs_plugin_loader_wildcard_func (GsPluginLoader *plugin_loader)
 
 	list = gs_plugin_loader_get_popular (plugin_loader,
 					     GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
+					     GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					     NULL,
 					     &error);
 	g_assert_no_error (error);
@@ -1301,8 +1383,9 @@ main (int argc, char **argv)
 		"dpkg",
 		"dummy",
 		"epiphany",
-		"flatpak-user",
+		"flatpak",
 		"fwupd",
+		"generic-updates",
 		"hardcoded-blacklist",
 		"desktop-categories",
 		"desktop-menu-path",
@@ -1411,7 +1494,7 @@ main (int argc, char **argv)
 		"      <keyword>Bingo</keyword>\n"
 		"    </keywords>\n"
 		"    <metadata>\n"
-		"      <value key=\"GnomeSoftware::Plugin\">flatpak-user</value>\n"
+		"      <value key=\"GnomeSoftware::Plugin\">flatpak</value>\n"
 		"    </metadata>\n"
 		"    <project_license>GPL-2.0+</project_license>\n"
 		"    <url type=\"homepage\">http://127.0.0.1/</url>\n"
@@ -1431,17 +1514,22 @@ main (int argc, char **argv)
 	g_test_add_func ("/gnome-software/os-release", gs_os_release_func);
 	g_test_add_func ("/gnome-software/app", gs_app_func);
 	g_test_add_func ("/gnome-software/app{unique-id}", gs_app_unique_id_func);
+	g_test_add_func ("/gnome-software/app{thread}", gs_app_thread_func);
 	g_test_add_func ("/gnome-software/plugin", gs_plugin_func);
 	g_test_add_func ("/gnome-software/plugin{global-cache}", gs_plugin_global_cache_func);
 	g_test_add_func ("/gnome-software/auth{secret}", gs_auth_secret_func);
 
 	/* we can only load this once per process */
 	plugin_loader = gs_plugin_loader_new ();
-	gs_plugin_loader_set_network_status (plugin_loader, TRUE);
 	g_signal_connect (plugin_loader, "status-changed",
 			  G_CALLBACK (gs_plugin_loader_status_changed_cb), NULL);
-	gs_plugin_loader_set_location (plugin_loader, "./plugins/.libs");
-	ret = gs_plugin_loader_setup (plugin_loader, (gchar**) whitelist, NULL, &error);
+	gs_plugin_loader_set_location (plugin_loader, LOCALPLUGINDIR);
+	ret = gs_plugin_loader_setup (plugin_loader,
+				      (gchar**) whitelist,
+				      NULL,
+				      GS_PLUGIN_FAILURE_FLAGS_NONE,
+				      NULL,
+				      &error);
 	g_assert_no_error (error);
 	g_assert (ret);
 	g_assert (!gs_plugin_loader_get_enabled (plugin_loader, "notgoingtoexist"));
