@@ -577,6 +577,8 @@ gs_shell_details_refresh_screenshots (GsShellDetails *self)
 	case AS_APP_KIND_SOURCE:
 	case AS_APP_KIND_FIRMWARE:
 	case AS_APP_KIND_DRIVER:
+	case AS_APP_KIND_INPUT_METHOD:
+	case AS_APP_KIND_LOCALIZATION:
 		gtk_widget_set_visible (self->box_details_screenshot_fallback, FALSE);
 		break;
 	default:
@@ -1102,6 +1104,8 @@ gs_shell_details_authenticate_cb (GtkDialog *dialog,
 					      helper->app,
 					      helper->review,
 					      helper->action,
+					      GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS |
+					      GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					      helper->self->cancellable,
 					      gs_shell_details_app_set_review_cb,
 					      helper);
@@ -1158,6 +1162,8 @@ gs_shell_details_review_button_clicked_cb (GsReviewRow *row,
 					      helper->app,
 					      helper->review,
 					      helper->action,
+					      GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS |
+					      GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					      self->cancellable,
 					      gs_shell_details_app_set_review_cb,
 					      helper);
@@ -1250,10 +1256,6 @@ gs_shell_details_refresh_reviews (GsShellDetails *self)
 		}
 	}
 
-	/* only show the button if there are more to show */
-	gtk_widget_set_visible (self->button_more_reviews,
-				n_reviews > SHOW_NR_REVIEWS_INITIAL);
-
 	/* add all the reviews */
 	gs_container_remove_all (GTK_CONTAINER (self->list_box_reviews));
 	reviews = gs_app_get_reviews (self->app);
@@ -1273,10 +1275,25 @@ gs_shell_details_refresh_reviews (GsShellDetails *self)
 		gs_review_row_set_actions (GS_REVIEW_ROW (row), actions);
 		gtk_container_add (GTK_CONTAINER (self->list_box_reviews), row);
 		gtk_widget_set_visible (row, i < SHOW_NR_REVIEWS_INITIAL);
+		gs_review_row_set_network_available (GS_REVIEW_ROW (row),
+						     gs_plugin_loader_get_network_available (self->plugin_loader));
 	}
 
+	/* only show the button if there are more to show */
+	gtk_widget_set_visible (self->button_more_reviews,
+				reviews->len > SHOW_NR_REVIEWS_INITIAL);
+
 	/* show the button only if the user never reviewed */
 	gtk_widget_set_visible (self->button_review, show_review_button);
+	if (gs_plugin_loader_get_network_available (self->plugin_loader)) {
+		gtk_widget_set_sensitive (self->button_review, TRUE);
+		gtk_widget_set_tooltip_text (self->button_review, NULL);
+	} else {
+		gtk_widget_set_sensitive (self->button_review, FALSE);
+		gtk_widget_set_tooltip_text (self->button_review,
+					     /* TRANSLATORS: we need a remote server to process */
+					     _("You need internet access to write a review"));
+	}
 }
 
 static void
@@ -1306,6 +1323,7 @@ gs_shell_details_app_refine2 (GsShellDetails *self)
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEW_RATINGS |
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEWS,
+					   GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 					   self->cancellable,
 					   gs_shell_details_app_refine2_cb,
 					   self);
@@ -1497,6 +1515,7 @@ gs_shell_details_set_filename (GsShellDetails *self, const gchar *filename)
 					    GS_PLUGIN_REFINE_FLAGS_REQUIRE_PROVENANCE |
 					    GS_PLUGIN_REFINE_FLAGS_REQUIRE_RELATED |
 					    GS_PLUGIN_REFINE_FLAGS_REQUIRE_PERMISSIONS,
+					    GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 					    self->cancellable,
 					    gs_shell_details_file_to_app_cb,
 					    self);
@@ -1519,6 +1538,7 @@ gs_shell_details_load (GsShellDetails *self)
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_SETUP_ACTION |
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_PROVENANCE |
 					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_ADDONS,
+					   GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 					   self->cancellable,
 					   gs_shell_details_app_refine_cb,
 					   self);
@@ -1633,7 +1653,8 @@ gs_shell_details_app_install_button_cb (GtkWidget *widget, GsShellDetails *self)
 		return;
 	}
 
-	gs_page_install_app (GS_PAGE (self), self->app, self->cancellable);
+	gs_page_install_app (GS_PAGE (self), self->app, GS_SHELL_INTERACTION_FULL,
+			     self->cancellable);
 }
 
 static void
@@ -1653,7 +1674,8 @@ gs_shell_details_addon_selected_cb (GsAppAddonRow *row,
 	case AS_APP_STATE_UPDATABLE:
 	case AS_APP_STATE_UPDATABLE_LIVE:
 		if (gs_app_addon_row_get_selected (row)) {
-			gs_page_install_app (GS_PAGE (self), addon, self->cancellable);
+			gs_page_install_app (GS_PAGE (self), addon, GS_SHELL_INTERACTION_FULL,
+					     self->cancellable);
 		} else {
 			gs_page_remove_app (GS_PAGE (self), addon, self->cancellable);
 			/* make sure the addon checkboxes are synced if the
@@ -1671,6 +1693,11 @@ static void
 gs_shell_details_app_launch_button_cb (GtkWidget *widget, GsShellDetails *self)
 {
 	g_autoptr(GCancellable) cancellable = g_cancellable_new ();
+
+	/* hide the notification */
+	g_application_withdraw_notification (g_application_get_default (),
+					     "installed");
+
 	g_set_object (&self->cancellable, cancellable);
 	gs_page_launch_app (GS_PAGE (self), self->app, self->cancellable);
 }
@@ -1729,6 +1756,8 @@ gs_shell_details_review_response_cb (GtkDialog *dialog,
 					      helper->app,
 					      helper->review,
 					      helper->action,
+					      GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS |
+					      GS_PLUGIN_FAILURE_FLAGS_FATAL_ANY,
 					      self->cancellable,
 					      gs_shell_details_app_set_review_cb,
 					      helper);
@@ -1779,27 +1808,27 @@ gs_shell_details_content_rating_button_cb (GtkWidget *widget, GsShellDetails *se
 	struct {
 		const gchar *ids[5];	/* ordered inside from worst to best */
 	} id_map[] = {
-		{ "violence-bloodshed",
+		{{"violence-bloodshed",
 		  "violence-realistic",
 		  "violence-fantasy",
-		  "violence-cartoon", NULL },
-		{ "violence-sexual", NULL },
-		{ "drugs-alcohol", NULL },
-		{ "drugs-narcotics", NULL },
-		{ "sex-nudity", NULL },
-		{ "sex-themes", NULL },
-		{ "language-profanity", NULL },
-		{ "language-humor", NULL },
-		{ "language-discrimination", NULL },
-		{ "money-advertising", NULL },
-		{ "money-gambling", NULL },
-		{ "money-purchasing", NULL },
-		{ "social-audio",
+		  "violence-cartoon", NULL }},
+		{{"violence-sexual", NULL }},
+		{{"drugs-alcohol", NULL }},
+		{{"drugs-narcotics", NULL }},
+		{{"sex-nudity", NULL }},
+		{{"sex-themes", NULL }},
+		{{"language-profanity", NULL }},
+		{{"language-humor", NULL }},
+		{{"language-discrimination", NULL }},
+		{{"money-advertising", NULL }},
+		{{"money-gambling", NULL }},
+		{{"money-purchasing", NULL }},
+		{{"social-audio",
 		  "social-chat",
 		  "social-contacts",
-		  "social-info", NULL },
-		{ "social-location", NULL },
-		{ NULL }
+		  "social-info", NULL }},
+		{{"social-location", NULL }},
+		{{ NULL }}
 	};
 
 	/* get the worst thing */
@@ -1973,6 +2002,14 @@ gs_shell_details_license_unknown_cb (GtkWidget *widget, GsShellDetails *self)
 	gtk_widget_show (self->popover_license_unknown);
 }
 
+static void
+gs_shell_details_network_available_notify_cb (GsPluginLoader *plugin_loader,
+					      GParamSpec *pspec,
+					      GsShellDetails *self)
+{
+	gs_shell_details_refresh_reviews (self);
+}
+
 void
 gs_shell_details_setup (GsShellDetails *self,
 			GsShell	*shell,
@@ -1998,6 +2035,11 @@ gs_shell_details_setup (GsShellDetails *self,
 			  G_CALLBACK (gs_shell_details_write_review_cb),
 			  self);
 
+	/* hide some UI when offline */
+	g_signal_connect_object (self->plugin_loader, "notify::network-available",
+				 G_CALLBACK (gs_shell_details_network_available_notify_cb),
+				 self, 0);
+
 	/* setup details */
 	g_signal_connect (self->button_install, "clicked",
 			  G_CALLBACK (gs_shell_details_app_install_button_cb),
