@@ -264,7 +264,8 @@ app_row_button_clicked_cb (GsAppRow *app_row,
 	app = gs_app_row_get_app (app_row);
 	if (gs_app_get_state (app) == AS_APP_STATE_AVAILABLE ||
 	    gs_app_get_state (app) == AS_APP_STATE_AVAILABLE_LOCAL)
-		gs_page_install_app (GS_PAGE (self), app, self->search_cancellable);
+		gs_page_install_app (GS_PAGE (self), app, GS_SHELL_INTERACTION_FULL,
+				     self->search_cancellable);
 	else if (gs_app_get_state (app) == AS_APP_STATE_INSTALLED)
 		gs_page_remove_app (GS_PAGE (self), app, self->search_cancellable);
 	else
@@ -694,6 +695,7 @@ gs_shell_extras_load (GsShellExtras *self, GPtrArray *array_search_data)
 			                                     GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON |
 			                                     GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
 			                                     GS_PLUGIN_REFINE_FLAGS_ALLOW_PACKAGES,
+			                                     GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 			                                     self->search_cancellable,
 			                                     search_files_cb,
 			                                     search_data);
@@ -706,6 +708,7 @@ gs_shell_extras_load (GsShellExtras *self, GPtrArray *array_search_data)
 			                                    GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON |
 			                                    GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
 			                                    GS_PLUGIN_REFINE_FLAGS_ALLOW_PACKAGES,
+			                                    GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 			                                    self->search_cancellable,
 			                                    file_to_app_cb,
 			                                    search_data);
@@ -722,6 +725,7 @@ gs_shell_extras_load (GsShellExtras *self, GPtrArray *array_search_data)
 			                                             GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENSE |
 			                                             GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
 			                                             GS_PLUGIN_REFINE_FLAGS_ALLOW_PACKAGES,
+			                                             GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 			                                             self->search_cancellable,
 			                                             get_search_what_provides_cb,
 			                                             search_data);
