@@ -44,7 +44,6 @@ struct _GsShellSearch
 	gchar			*appid_to_show;
 	gchar			*value;
 	guint			 waiting_id;
-	GtkWidget		*search_button;
 
 	GtkWidget		*list_box_search;
 	GtkWidget		*scrolledwindow_search;
@@ -71,12 +70,15 @@ gs_shell_search_app_row_clicked_cb (GsAppRow *app_row,
 	GsApp *app;
 	app = gs_app_row_get_app (app_row);
 	if (gs_app_get_state (app) == AS_APP_STATE_AVAILABLE)
-		gs_page_install_app (GS_PAGE (self), app, self->cancellable);
+		gs_page_install_app (GS_PAGE (self), app, GS_SHELL_INTERACTION_FULL,
+				     self->cancellable);
 	else if (gs_app_get_state (app) == AS_APP_STATE_INSTALLED)
 		gs_page_remove_app (GS_PAGE (self), app, self->cancellable);
 	else if (gs_app_get_state (app) == AS_APP_STATE_UNAVAILABLE) {
 		if (gs_app_get_url (app, AS_URL_KIND_MISSING) == NULL) {
-			gs_page_install_app (GS_PAGE (self), app, self->cancellable);
+			gs_page_install_app (GS_PAGE (self), app,
+					     GS_SHELL_INTERACTION_FULL,
+					     self->cancellable);
 			return;
 		}
 		gs_app_show_url (app, AS_URL_KIND_MISSING);
@@ -134,7 +136,6 @@ gs_shell_search_get_search_cb (GObject *source_object,
 	for (i = 0; i < gs_app_list_length (list); i++) {
 		app = gs_app_list_index (list, i);
 		app_row = gs_app_row_new (app);
-		gs_app_row_set_show_sandbox (GS_APP_ROW (app_row), TRUE);
 		if (!gs_app_has_quirk (app, AS_APP_QUIRK_PROVENANCE) ||
 		    gs_utils_list_has_app_fuzzy (list, app))
 			gs_app_row_set_show_source (GS_APP_ROW (app_row), TRUE);
@@ -198,6 +199,7 @@ gs_shell_search_load (GsShellSearch *self)
 				       GS_PLUGIN_REFINE_FLAGS_REQUIRE_PERMISSIONS |
 				       GS_PLUGIN_REFINE_FLAGS_REQUIRE_ORIGIN_HOSTNAME |
 				       GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING,
+				       GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 				       self->search_cancellable,
 				       gs_shell_search_get_search_cb,
 				       self);
@@ -257,7 +259,8 @@ gs_shell_search_switch_to (GsPage *page, gboolean scroll_up)
 	gtk_widget_show (widget);
 
 	/* hardcode */
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->search_button), TRUE);
+	widget = GTK_WIDGET (gtk_builder_get_object (self->builder, "search_button"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 
 	if (scroll_up) {
 		GtkAdjustment *adj;
@@ -384,14 +387,6 @@ gs_shell_search_app_removed (GsPage *page, GsApp *app)
 	gs_shell_search_reload (page);
 }
 
-static void
-gs_shell_search_search_button_cb (GtkButton *button, GsShellSearch *self)
-{
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
-		return;
-	gs_shell_change_mode (self->shell, GS_SHELL_MODE_OVERVIEW, NULL, TRUE);
-}
-
 void
 gs_shell_search_setup (GsShellSearch *self,
 		       GsShell *shell,
@@ -421,12 +416,6 @@ gs_shell_search_setup (GsShellSearch *self,
 				    gs_shell_search_sort_func,
 				    self, NULL);
 
-	/* search button */
-	self->search_button = gs_search_button_new (NULL);
-	gs_page_set_header_end_widget (GS_PAGE (self), self->search_button);
-	g_signal_connect (self->search_button, "clicked",
-			  G_CALLBACK (gs_shell_search_search_button_cb), self);
-
 	/* chain up */
 	gs_page_setup (GS_PAGE (self),
 	               shell,
