@@ -78,8 +78,6 @@ struct _GsShellUpdates
 	gboolean		 all_updates_are_live;
 	gboolean		 any_require_reboot;
 	GsShell			*shell;
-	GNetworkMonitor		*network_monitor;
-	gulong			 network_changed_handler;
 	GsPluginStatus		 last_status;
 	GsShellUpdatesState	 state;
 	GsShellUpdatesFlags	 result_flags;
@@ -319,14 +317,15 @@ gs_shell_updates_update_ui_state (GsShellUpdates *self)
 		if (self->result_flags != GS_SHELL_UPDATES_FLAG_NONE) {
 			gtk_widget_show (self->button_refresh);
 		} else {
-			if (self->network_monitor != NULL &&
-			    g_network_monitor_get_network_metered (self->network_monitor) &&
+			if (gs_plugin_loader_get_network_metered (self->plugin_loader) &&
 			    !self->has_agreed_to_mobile_data)
 				allow_mobile_refresh = FALSE;
 			gtk_widget_set_visible (self->button_refresh, allow_mobile_refresh);
 		}
 		break;
 	}
+	gtk_widget_set_sensitive (self->button_refresh,
+				  gs_plugin_loader_get_network_available (self->plugin_loader));
 
 	/* headerbar update button */
 	gtk_widget_set_visible (self->button_update_all,
@@ -360,21 +359,15 @@ gs_shell_updates_update_ui_state (GsShellUpdates *self)
 			break;
 		}
 
-		/* we just don't know */
-		if (self->network_monitor == NULL) {
-			gtk_stack_set_visible_child_name (GTK_STACK (self->stack_updates), "uptodate");
-			break;
-		}
-
 		/* check we have a "free" network connection */
-		if (g_network_monitor_get_network_available (self->network_monitor) &&
-			   !g_network_monitor_get_network_metered (self->network_monitor)) {
+		if (gs_plugin_loader_get_network_available (self->plugin_loader) &&
+		    !gs_plugin_loader_get_network_metered (self->plugin_loader)) {
 			gtk_stack_set_visible_child_name (GTK_STACK (self->stack_updates), "uptodate");
 			break;
 		}
 
 		/* expensive network connection */
-		if (g_network_monitor_get_network_metered (self->network_monitor)) {
+		if (gs_plugin_loader_get_network_metered (self->plugin_loader)) {
 			if (self->has_agreed_to_mobile_data) {
 				gtk_stack_set_visible_child_name (GTK_STACK (self->stack_updates), "uptodate");
 			} else {
@@ -465,10 +458,11 @@ gs_shell_updates_decrement_refresh_count (GsShellUpdates *self)
 	gs_shell_profile_dump (self->shell);
 }
 
+
 static void
-gs_shell_updates_notify_network_state_cb (GNetworkMonitor *network_monitor,
-					  gboolean available,
-					  GsShellUpdates *self)
+gs_shell_updates_network_available_notify_cb (GsPluginLoader *plugin_loader,
+					      GParamSpec *pspec,
+					      GsShellUpdates *self)
 {
 	gs_shell_updates_update_ui_state (self);
 }
@@ -607,6 +601,7 @@ gs_shell_updates_load (GsShellUpdates *self)
 	self->action_cnt++;
 	gs_plugin_loader_get_updates_async (self->plugin_loader,
 					    refine_flags,
+					    GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 					    self->cancellable,
 					    (GAsyncReadyCallback) gs_shell_updates_get_updates_cb,
 					    self);
@@ -616,6 +611,7 @@ gs_shell_updates_load (GsShellUpdates *self)
 		refine_flags |= GS_PLUGIN_REFINE_FLAGS_REQUIRE_UPGRADE_REMOVED;
 		gs_plugin_loader_get_distro_upgrades_async (self->plugin_loader,
 							    refine_flags,
+							    GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 							    self->cancellable,
 							    gs_shell_updates_get_upgrades_cb,
 							    self);
@@ -765,6 +761,7 @@ gs_shell_updates_get_new_updates (GsShellUpdates *self)
 	gs_plugin_loader_refresh_async (self->plugin_loader,
 					10 * 60,
 					refresh_flags,
+					GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 					self->cancellable_refresh,
 					(GAsyncReadyCallback) gs_shell_updates_refresh_cb,
 					self);
@@ -831,19 +828,13 @@ gs_shell_updates_button_refresh_cb (GtkWidget *widget,
 		return;
 	}
 
-	/* we don't know the network state */
-	if (self->network_monitor == NULL) {
-		gs_shell_updates_get_new_updates (self);
-		return;
-	}
-
 	/* check we have a "free" network connection */
-	if (g_network_monitor_get_network_available (self->network_monitor) &&
-	    !g_network_monitor_get_network_metered (self->network_monitor)) {
+	if (gs_plugin_loader_get_network_available (self->plugin_loader) &&
+	    !gs_plugin_loader_get_network_metered (self->plugin_loader)) {
 		gs_shell_updates_get_new_updates (self);
 
 	/* expensive network connection */
-	} else if (g_network_monitor_get_network_metered (self->network_monitor)) {
+	} else if (gs_plugin_loader_get_network_metered (self->plugin_loader)) {
 		if (self->has_agreed_to_mobile_data) {
 			gs_shell_updates_get_new_updates (self);
 			return;
@@ -937,6 +928,7 @@ gs_shell_updates_reboot_failed_cb (GObject *source, GAsyncResult *res, gpointer
 	gs_plugin_loader_app_action_async (self->plugin_loader,
 					   gs_app_list_index (apps, 0),
 					   GS_PLUGIN_ACTION_UPDATE_CANCEL,
+					   GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 					   self->cancellable,
 					   cancel_trigger_failed_cb,
 					   self);
@@ -1002,6 +994,7 @@ gs_shell_updates_button_update_all_cb (GtkButton      *button,
 	apps = gs_update_list_get_apps (GS_UPDATE_LIST (self->list_box_updates));
 	gs_plugin_loader_update_async (self->plugin_loader,
 				       apps,
+				       GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 				       self->cancellable,
 				       (GAsyncReadyCallback) gs_shell_updates_perform_update_cb,
 				       self);
@@ -1064,6 +1057,7 @@ gs_shell_updates_upgrade_download_cb (GsUpgradeBanner *upgrade_banner,
 	gs_plugin_loader_app_action_async (self->plugin_loader,
 					   app,
 					   GS_PLUGIN_ACTION_UPGRADE_DOWNLOAD,
+					   GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 					   self->cancellable_upgrade_download,
 					   upgrade_download_finished_cb,
 					   helper);
@@ -1099,6 +1093,7 @@ upgrade_reboot_failed_cb (GObject *source,
 	gs_plugin_loader_app_action_async (self->plugin_loader,
 					   app,
 					   GS_PLUGIN_ACTION_UPDATE_CANCEL,
+					   GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 					   self->cancellable,
 					   cancel_trigger_failed_cb,
 					   self);
@@ -1146,6 +1141,7 @@ trigger_upgrade (GsShellUpdates *self)
 	gs_plugin_loader_app_action_async (self->plugin_loader,
 	                                   upgrade,
 	                                   GS_PLUGIN_ACTION_UPGRADE_TRIGGER,
+	                                   GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 	                                   self->cancellable,
 	                                   upgrade_trigger_finished_cb,
 	                                   self);
@@ -1329,6 +1325,9 @@ gs_shell_updates_setup (GsShellUpdates *self,
 	g_signal_connect_object (self->plugin_loader, "notify::allow-updates",
 				 G_CALLBACK (gs_shell_updates_allow_updates_notify_cb),
 				 self, 0);
+	g_signal_connect_object (self->plugin_loader, "notify::network-available",
+				 G_CALLBACK (gs_shell_updates_network_available_notify_cb),
+				 self, 0);
 	self->builder = g_object_ref (builder);
 	self->cancellable = g_object_ref (cancellable);
 
@@ -1387,12 +1386,6 @@ gs_shell_updates_setup (GsShellUpdates *self,
 	if (!gs_plugin_loader_get_allow_updates (self->plugin_loader))
 		self->state = GS_SHELL_UPDATES_STATE_MANAGED;
 
-	if (self->network_monitor != NULL) {
-		self->network_changed_handler = g_signal_connect (self->network_monitor, "network-changed",
-						G_CALLBACK (gs_shell_updates_notify_network_state_cb),
-						self);
-	}
-
 	/* chain up */
 	gs_page_setup (GS_PAGE (self),
 	               shell,
@@ -1405,10 +1398,6 @@ gs_shell_updates_dispose (GObject *object)
 {
 	GsShellUpdates *self = GS_SHELL_UPDATES (object);
 
-	if (self->network_changed_handler != 0) {
-		g_signal_handler_disconnect (self->network_monitor, self->network_changed_handler);
-		self->network_changed_handler = 0;
-	}
 	if (self->cancellable_refresh != NULL) {
 		g_cancellable_cancel (self->cancellable_refresh);
 		g_clear_object (&self->cancellable_refresh);
@@ -1457,7 +1446,6 @@ gs_shell_updates_init (GsShellUpdates *self)
 
 	gtk_widget_init_template (GTK_WIDGET (self));
 
-	self->network_monitor = g_network_monitor_get_default ();
 	self->state = GS_SHELL_UPDATES_STATE_STARTUP;
 	self->settings = g_settings_new ("org.gnome.software");
 	self->desktop_settings = g_settings_new ("org.gnome.desktop.interface");
