@@ -25,8 +25,6 @@
 #include <string.h>
 #include <glib/gi18n.h>
 
-#include "gd-notification.h"
-
 #include "gs-common.h"
 #include "gs-shell.h"
 #include "gs-shell-details.h"
@@ -87,6 +85,7 @@ typedef struct
 	gulong			 search_changed_id;
 	gchar			*events_info_uri;
 	gboolean		 profile_mode;
+	gboolean		 in_mode_change;
 } GsShellPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GsShell, gs_shell, G_TYPE_OBJECT)
@@ -278,10 +277,16 @@ gs_shell_change_mode (GsShell *shell,
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "header_selection_menu_button"));
 	gtk_widget_hide (widget);
 
+	priv->in_mode_change = TRUE;
+	/* only show the search button in overview and search pages */
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "search_button"));
+	gtk_widget_set_visible (widget, mode == GS_SHELL_MODE_OVERVIEW ||
+					mode == GS_SHELL_MODE_SEARCH);
 	/* hide unless we're going to search */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "search_bar"));
 	gtk_search_bar_set_search_mode (GTK_SEARCH_BAR (widget),
 					mode == GS_SHELL_MODE_SEARCH);
+	priv->in_mode_change = FALSE;
 
 	context = gtk_widget_get_style_context (GTK_WIDGET (gtk_builder_get_object (priv->builder, "header")));
 	gtk_style_context_remove_class (context, "selection-mode");
@@ -362,7 +367,9 @@ gs_shell_change_mode (GsShell *shell,
 				mode != GS_SHELL_MODE_SEARCH &&
 				!g_queue_is_empty (priv->back_entry_stack));
 
+	priv->in_mode_change = TRUE;
 	gs_page_switch_to (new_page, scroll_up);
+	priv->in_mode_change = FALSE;
 
 	/* update header bar widgets */
 	widget = gs_page_get_header_start_widget (new_page);
@@ -473,10 +480,11 @@ gs_shell_plugin_events_more_info_cb (GtkWidget *widget, GsShell *shell)
 }
 
 static void
-gs_shell_back_button_cb (GtkWidget *widget, GsShell *shell)
+gs_shell_go_back (GsShell *shell)
 {
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 	BackEntry *entry;
+	GtkWidget *widget;
 
 	g_return_if_fail (!g_queue_is_empty (priv->back_entry_stack));
 
@@ -526,6 +534,12 @@ gs_shell_back_button_cb (GtkWidget *widget, GsShell *shell)
 	free_back_entry (entry);
 }
 
+static void
+gs_shell_back_button_cb (GtkWidget *widget, GsShell *shell)
+{
+	gs_shell_go_back (shell);
+}
+
 static void
 initial_overview_load_done (GsShellOverview *shell_overview, gpointer data)
 {
@@ -588,6 +602,36 @@ search_changed_handler (GObject *entry, GsShell *shell)
 	}
 }
 
+static void
+search_button_clicked_cb (GtkToggleButton *toggle_button, GsShell *shell)
+{
+	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
+	GtkWidget *search_bar;
+
+	search_bar = GTK_WIDGET (gtk_builder_get_object (priv->builder, "search_bar"));
+	gtk_search_bar_set_search_mode (GTK_SEARCH_BAR (search_bar),
+	                                gtk_toggle_button_get_active (toggle_button));
+
+	if (priv->in_mode_change)
+		return;
+
+	/* go back when exiting the search view */
+	if (priv->mode == GS_SHELL_MODE_SEARCH &&
+	    !gtk_toggle_button_get_active (toggle_button))
+		gs_shell_go_back (shell);
+}
+
+static void
+search_mode_enabled_cb (GtkSearchBar *search_bar, GParamSpec *pspec, GsShell *shell)
+{
+	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
+	GtkWidget *search_button;
+
+	search_button = GTK_WIDGET (gtk_builder_get_object (priv->builder, "search_button"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (search_button),
+	                              gtk_search_bar_get_search_mode (search_bar));
+}
+
 static gboolean
 window_key_press_event (GtkWidget *win, GdkEventKey *event, GsShell *shell)
 {
@@ -641,6 +685,12 @@ main_window_closed_cb (GtkWidget *dialog, GdkEvent *event, gpointer user_data)
 	GsShell *shell = user_data;
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 
+	/* hide any notifications */
+	g_application_withdraw_notification (g_application_get_default (),
+					     "installed");
+	g_application_withdraw_notification (g_application_get_default (),
+					     "install-resources");
+
 	/* When the window is closed, reset the initial mode to overview */
 	priv->mode = GS_SHELL_MODE_OVERVIEW;
 
@@ -701,7 +751,7 @@ gs_shell_show_event_app_notify (GsShell *shell,
 
 	/* set visible */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "notification_event"));
-	gtk_widget_set_visible (widget, TRUE);
+	gtk_revealer_set_reveal_child (GTK_REVEALER (widget), TRUE);
 
 	/* sources button */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_events_sources"));
@@ -1334,11 +1384,13 @@ gs_shell_show_event_file_to_app (GsShell *shell, GsPluginEvent *event)
 static gboolean
 gs_shell_show_event_fallback (GsShell *shell, GsPluginEvent *event)
 {
+	GsApp *app = gs_plugin_event_get_app (event);
 	GsApp *origin = gs_plugin_event_get_origin (event);
 	GsShellEventButtons buttons = GS_SHELL_EVENT_BUTTON_NONE;
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 	const GError *error = gs_plugin_event_get_error (event);
 	g_autoptr(GString) str = g_string_new (NULL);
+	g_autofree gchar *str_app = NULL;
 	g_autofree gchar *str_origin = NULL;
 
 	switch (error->code) {
@@ -1358,6 +1410,20 @@ gs_shell_show_event_fallback (GsShell *shell, GsPluginEvent *event)
 					"and try again"));
 		buttons |= GS_SHELL_EVENT_BUTTON_NO_SPACE;
 		break;
+	case GS_PLUGIN_ERROR_RESTART_REQUIRED:
+		if (app != NULL) {
+			str_app = gs_shell_get_title_from_app (app);
+			/* TRANSLATORS: failure text for the in-app notification,
+			 * where the %s is the application name (e.g. "GIMP") */
+			g_string_append_printf (str, _("%s needs to be restarted "
+						       "to use new plugins."),
+						str_app);
+		} else {
+			/* TRANSLATORS: failure text for the in-app notification */
+			g_string_append (str, _("This application needs to be "
+						"restarted to use new plugins."));
+		}
+		break;
 	default:
 		break;
 	}
@@ -1442,7 +1508,7 @@ gs_shell_rescan_events (GsShell *shell)
 	/* nothing to show */
 	g_debug ("no events to show");
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "notification_event"));
-	gtk_widget_set_visible (widget, FALSE);
+	gtk_revealer_set_reveal_child (GTK_REVEALER (widget), FALSE);
 }
 
 static void
@@ -1454,7 +1520,7 @@ gs_shell_events_notify_cb (GsPluginLoader *plugin_loader,
 }
 
 static void
-gs_shell_plugin_event_dismissed_cb (GdNotification *notification, GsShell *shell)
+gs_shell_plugin_event_dismissed_cb (GtkButton *button, GsShell *shell)
 {
 	GPtrArray *events;
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
@@ -1524,6 +1590,17 @@ gs_shell_setup (GsShell *shell, GsPluginLoader *plugin_loader, GCancellable *can
 	g_signal_connect_after (priv->main_window, "button_press_event",
 				G_CALLBACK (window_button_press_event), shell);
 
+	/* show the search bar when clicking on the search button */
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "search_button"));
+	g_signal_connect (widget, "clicked",
+	                  G_CALLBACK (search_button_clicked_cb),
+	                  shell);
+	/* set the search button enabled when search bar appears */
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "search_bar"));
+	g_signal_connect (widget, "notify::search-mode-enabled",
+	                  G_CALLBACK (search_mode_enabled_cb),
+	                  shell);
+
 	/* setup buttons */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_back"));
 	g_signal_connect (widget, "clicked",
@@ -1548,8 +1625,8 @@ gs_shell_setup (GsShell *shell, GsPluginLoader *plugin_loader, GCancellable *can
 			  G_CALLBACK (gs_shell_overview_button_cb), shell);
 
 	/* set up in-app notification controls */
-	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "notification_event"));
-	g_signal_connect (widget, "dismissed",
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_events_dismiss"));
+	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gs_shell_plugin_event_dismissed_cb), shell);
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_events_sources"));
 	g_signal_connect (widget, "clicked",
@@ -1668,6 +1745,17 @@ gs_shell_get_mode_string (GsShell *shell)
 	return page_name[priv->mode];
 }
 
+void
+gs_shell_install (GsShell *shell, GsApp *app, GsShellInteraction interaction)
+{
+	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
+	save_back_entry (shell);
+	gs_shell_change_mode (shell, GS_SHELL_MODE_DETAILS,
+			      (gpointer) app, TRUE);
+	gs_page_install_app (GS_PAGE (priv->shell_details), app, interaction,
+			     priv->cancellable);
+}
+
 void
 gs_shell_show_installed_updates (GsShell *shell)
 {
@@ -1717,6 +1805,8 @@ gs_shell_show_category (GsShell *shell, GsCategory *category)
 void gs_shell_show_extras_search (GsShell *shell, const gchar *mode, gchar **resources)
 {
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
+
+	save_back_entry (shell);
 	gs_shell_extras_search (priv->shell_extras, mode, resources);
 	gs_shell_change_mode (shell, GS_SHELL_MODE_EXTRAS, NULL, TRUE);
 	gs_shell_activate (shell);
