@@ -70,6 +70,14 @@ gint		 gs_utils_get_wilson_rating	(guint64	 star1,
 						 guint64	 star3,
 						 guint64	 star4,
 						 guint64	 star5);
+void		 gs_utils_error_add_unique_id	(GError		**error,
+						 GsApp		*app);
+void		 gs_utils_error_strip_unique_id	(GError		*error);
+gboolean	 gs_utils_error_convert_gio	(GError		**perror);
+gboolean	 gs_utils_error_convert_gdbus	(GError		**perror);
+gboolean	 gs_utils_error_convert_gdk_pixbuf(GError	**perror);
+gboolean	 gs_utils_error_convert_json_glib (GError	**perror);
+gboolean	 gs_utils_error_convert_appstream (GError	**perror);
 
 G_END_DECLS
 
