@@ -47,19 +47,12 @@ struct _GsFlatpak {
 
 G_DEFINE_TYPE (GsFlatpak, gs_flatpak, G_TYPE_OBJECT)
 
-/* we have to do this until we hard dep on 0.6.11 */
-#define _FLATPAK_CHECK_VERSION(major,minor,micro)    \
-    (FLATPAK_MAJOR_VERSION > (major) || \
-     (FLATPAK_MAJOR_VERSION == (major) && FLATPAK_MINOR_VERSION > (minor)) || \
-     (FLATPAK_MAJOR_VERSION == (major) && FLATPAK_MINOR_VERSION == (minor) && \
-      FLATPAK_MICRO_VERSION >= (micro)))
-
 static gboolean
 gs_flatpak_refresh_appstream (GsFlatpak *self, guint cache_age,
 			      GsPluginRefreshFlags flags,
 			      GCancellable *cancellable, GError **error);
 
-static void
+void
 gs_plugin_flatpak_error_convert (GError **perror)
 {
 	GError *error = perror != NULL ? *perror : NULL;
@@ -149,6 +142,10 @@ gs_plugin_flatpak_changed_cb (GFileMonitor *monitor,
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GError) error_md = NULL;
 
+	/* don't refresh when it's us ourselves doing the change */
+	if (gs_plugin_has_flags (self->plugin, GS_PLUGIN_FLAGS_RUNNING_SELF))
+		return;
+
 	/* manually drop the cache */
 	if (!flatpak_installation_drop_caches (self->installation,
 					       NULL, &error)) {
@@ -410,8 +407,19 @@ gs_flatpak_rescan_appstream_store (GsFlatpak *self,
 gboolean
 gs_flatpak_setup (GsFlatpak *self, GCancellable *cancellable, GError **error)
 {
-	const gchar *destdir;
 	g_autoptr(AsProfileTask) ptask = NULL;
+	g_autoptr(GError) error_md = NULL;
+
+	ptask = as_profile_start_literal (gs_plugin_get_profile (self->plugin),
+					  "flatpak::setup");
+	g_assert (ptask != NULL);
+
+	if (!gs_flatpak_refresh_appstream (self, G_MAXUINT, 0,
+					   cancellable,
+					   &error_md)) {
+		g_warning ("failed to get initial available data on setup: %s",
+			   error_md->message);
+	}
 
 	/* load just the wildcards */
 	if (!as_store_load (self->store,
@@ -424,31 +432,6 @@ gs_flatpak_setup (GsFlatpak *self, GCancellable *cancellable, GError **error)
 		return FALSE;
 	}
 
-	/* we use a permissions helper to elevate privs */
-	ptask = as_profile_start_literal (gs_plugin_get_profile (self->plugin),
-					  "flatpak::setup");
-	g_assert (ptask != NULL);
-	destdir = g_getenv ("GS_SELF_TEST_FLATPACK_DATADIR");
-	if (destdir != NULL) {
-		g_autofree gchar *full_path = g_build_filename (destdir,
-								"flatpak",
-								NULL);
-		g_autoptr(GFile) file = g_file_new_for_path (full_path);
-		g_debug ("using custom flatpak path %s", full_path);
-		self->installation = flatpak_installation_new_for_path (file, TRUE,
-									cancellable,
-									error);
-	} else if (self->scope == AS_APP_SCOPE_SYSTEM) {
-		self->installation = flatpak_installation_new_system (cancellable,
-								      error);
-	} else if (self->scope == AS_APP_SCOPE_USER) {
-		self->installation = flatpak_installation_new_user (cancellable,
-								    error);
-	}
-	if (self->installation == NULL) {
-		gs_plugin_flatpak_error_convert (error);
-		return FALSE;
-	}
 
 	/* watch for changes */
 	self->monitor = flatpak_installation_create_monitor (self->installation,
@@ -624,6 +607,7 @@ gs_flatpak_set_metadata (GsFlatpak *self, GsApp *app, FlatpakRef *xref)
 {
 	gs_app_set_bundle_kind (app, AS_BUNDLE_KIND_FLATPAK);
 	gs_app_set_management_plugin (app, gs_plugin_get_name (self->plugin));
+	gs_app_set_branch (app, flatpak_ref_get_branch (xref));
 	gs_app_set_flatpak_kind (app, flatpak_ref_get_kind (xref));
 	gs_app_set_flatpak_name (app, flatpak_ref_get_name (xref));
 	gs_app_set_flatpak_arch (app, flatpak_ref_get_arch (xref));
@@ -739,18 +723,9 @@ gs_flatpak_add_installed (GsFlatpak *self, GsAppList *list,
 			  GCancellable *cancellable,
 			  GError **error)
 {
-	g_autoptr(GError) error_md = NULL;
 	g_autoptr(GPtrArray) xrefs = NULL;
 	guint i;
 
-	/* if we've never ever run before, get the AppStream data */
-	if (!gs_flatpak_refresh_appstream (self, G_MAXUINT, 0,
-					   cancellable,
-					   &error_md)) {
-		g_warning ("failed to get initial available data: %s",
-			   error_md->message);
-	}
-
 	/* get apps and runtimes */
 	xrefs = flatpak_installation_list_installed_refs (self->installation,
 							  cancellable, error);
@@ -876,11 +851,6 @@ gs_flatpak_app_install_source (GsFlatpak *self, GsApp *app,
 	const gchar *branch;
 	g_autoptr(FlatpakRemote) xremote = NULL;
 
-	/* only process this source if was created for this plugin */
-	if (g_strcmp0 (gs_app_get_management_plugin (app),
-		       gs_plugin_get_name (self->plugin)) != 0)
-		return TRUE;
-
 	/* does the remote already exist and is disabled */
 	xremote = flatpak_installation_get_remote_by_name (self->installation,
 							   gs_app_get_id (app),
@@ -926,6 +896,7 @@ gs_flatpak_app_install_source (GsFlatpak *self, GsApp *app,
 						 xremote,
 						 cancellable,
 						 error)) {
+		gs_plugin_flatpak_error_convert (error);
 		gs_app_set_state_recover (app);
 		return FALSE;
 	}
@@ -965,6 +936,11 @@ gs_flatpak_add_updates (GsFlatpak *self, GsAppList *list,
 		/* check the application has already been downloaded */
 		commit = flatpak_ref_get_commit (FLATPAK_REF (xref));
 		latest_commit = flatpak_installed_ref_get_latest_commit (xref);
+		if (latest_commit == NULL) {
+			g_debug ("could not get latest commit for %s",
+				 flatpak_ref_get_name (FLATPAK_REF (xref)));
+			continue;
+		}
 		if (g_strcmp0 (commit, latest_commit) == 0) {
 			g_debug ("no downloaded update for %s",
 				 flatpak_ref_get_name (FLATPAK_REF (xref)));
@@ -1851,11 +1827,6 @@ gs_flatpak_refine_app (GsFlatpak *self,
 {
 	g_autoptr(AsProfileTask) ptask = NULL;
 
-	/* only process this app if was created by this plugin */
-	if (g_strcmp0 (gs_app_get_management_plugin (app),
-		       gs_plugin_get_name (self->plugin)) != 0)
-		return TRUE;
-
 	/* profile */
 	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
 				  "flatpak::refine{%s}",
@@ -1984,11 +1955,6 @@ gs_flatpak_launch (GsFlatpak *self,
 	GsApp *runtime;
 	const gchar *branch = NULL;
 
-	/* only process this app if was created by this plugin */
-	if (g_strcmp0 (gs_app_get_management_plugin (app),
-		       gs_plugin_get_name (self->plugin)) != 0)
-		return TRUE;
-
 	branch = gs_app_get_flatpak_branch (app);
 	if (branch == NULL)
 		branch = "master";
@@ -2049,6 +2015,7 @@ gs_flatpak_app_remove_source (GsFlatpak *self,
 						 gs_app_get_id (app),
 						 cancellable,
 						 error)) {
+		gs_plugin_flatpak_error_convert (error);
 		gs_app_set_state_recover (app);
 		return FALSE;
 	}
@@ -2062,11 +2029,6 @@ gs_flatpak_app_remove (GsFlatpak *self,
 		       GCancellable *cancellable,
 		       GError **error)
 {
-	/* only process this app if was created by this plugin */
-	if (g_strcmp0 (gs_app_get_management_plugin (app),
-		       gs_plugin_get_name (self->plugin)) != 0)
-		return TRUE;
-
 	/* refine to get basics */
 	if (!gs_flatpak_refine_app (self, app,
 				    GS_PLUGIN_REFINE_FLAGS_DEFAULT,
@@ -2090,6 +2052,7 @@ gs_flatpak_app_remove (GsFlatpak *self,
 					     gs_app_get_flatpak_branch (app),
 					     gs_flatpak_progress_cb, app,
 					     cancellable, error)) {
+		gs_plugin_flatpak_error_convert (error);
 		gs_app_set_state_recover (app);
 		return FALSE;
 	}
@@ -2113,11 +2076,6 @@ gs_flatpak_app_install (GsFlatpak *self,
 {
 	g_autoptr(FlatpakInstalledRef) xref = NULL;
 
-	/* only process this app if was created by this plugin */
-	if (g_strcmp0 (gs_app_get_management_plugin (app),
-		       gs_plugin_get_name (self->plugin)) != 0)
-		return TRUE;
-
 	/* ensure we have metadata and state */
 	if (!gs_flatpak_refine_app (self, app, 0, cancellable,
 				    error))
@@ -2191,8 +2149,16 @@ gs_flatpak_app_install (GsFlatpak *self,
 		}
 	}
 
-	/* use the source for local apps */
-	if (gs_app_get_local_file (app) != NULL) {
+	if (g_strcmp0 (gs_app_get_flatpak_file_type (app), "flatpak") == 0) {
+		/* no local_file set */
+		if (gs_app_get_origin (app) == NULL) {
+			g_set_error (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "no local_file set for %s",
+				     gs_app_get_unique_id (app));
+			return FALSE;
+		}
 		g_debug ("installing bundle %s", gs_app_get_unique_id (app));
 		xref = flatpak_installation_install_bundle (self->installation,
 							    gs_app_get_local_file (app),
@@ -2200,7 +2166,7 @@ gs_flatpak_app_install (GsFlatpak *self,
 							    app,
 							    cancellable, error);
 	} else {
-		/* no origin */
+		/* no origin set */
 		if (gs_app_get_origin (app) == NULL) {
 			g_set_error (error,
 				     GS_PLUGIN_ERROR,
@@ -2238,11 +2204,6 @@ gs_flatpak_update_app (GsFlatpak *self,
 {
 	g_autoptr(FlatpakInstalledRef) xref = NULL;
 
-	/* only process this app if was created by this plugin */
-	if (g_strcmp0 (gs_app_get_management_plugin (app),
-		       gs_plugin_get_name (self->plugin)) != 0)
-		return TRUE;
-
 	/* install */
 	gs_app_set_state (app, AS_APP_STATE_INSTALLING);
 	xref = flatpak_installation_update (self->installation,
@@ -2292,6 +2253,7 @@ gs_flatpak_file_to_app_bundle (GsFlatpak *self,
 
 	/* load metadata */
 	app = gs_plugin_create_app (self, FLATPAK_REF (xref_bundle));
+	gs_app_set_flatpak_file_type (app, "flatpak");
 	gs_app_set_kind (app, AS_APP_KIND_DESKTOP);
 	gs_app_set_state (app, AS_APP_STATE_AVAILABLE_LOCAL);
 	gs_app_set_size_installed (app, flatpak_bundle_ref_get_installed_size (xref_bundle));
@@ -2468,6 +2430,18 @@ gs_flatpak_file_to_app_repo (GsFlatpak *self,
 		return FALSE;
 	}
 
+	/* check version */
+	if (g_key_file_has_key (kf, "Flatpak Repo", "Version", NULL)) {
+		guint64 ver = g_key_file_get_uint64 (kf, "Flatpak Repo", "Version", NULL);
+		if (ver != 1) {
+			g_set_error (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "unsupported version %" G_GUINT64_FORMAT, ver);
+			return FALSE;
+		}
+	}
+
 	/* user specified a URL */
 	if (g_str_has_prefix (repo_gpgkey, "http://") ||
 	    g_str_has_prefix (repo_gpgkey, "https://")) {
@@ -2480,6 +2454,7 @@ gs_flatpak_file_to_app_repo (GsFlatpak *self,
 
 	/* create source */
 	app = gs_app_new (repo_id);
+	gs_app_set_flatpak_file_type (app, "flatpakrepo");
 	gs_app_set_kind (app, AS_APP_KIND_SOURCE);
 	gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
 	gs_app_set_name (app, GS_APP_QUALITY_NORMAL, repo_title);
@@ -2539,8 +2514,14 @@ gs_flatpak_file_to_app_ref (GsFlatpak *self,
 	g_autoptr(GBytes) ref_file_data = NULL;
 	g_autoptr(GsApp) app = NULL;
 	g_autoptr(FlatpakRemote) xremote = NULL;
+	g_autoptr(GKeyFile) kf = NULL;
 	g_autofree gchar *origin_url = NULL;
 	g_autofree gchar *origin_title = NULL;
+	g_autofree gchar *ref_comment = NULL;
+	g_autofree gchar *ref_description = NULL;
+	g_autofree gchar *ref_homepage = NULL;
+	g_autofree gchar *ref_icon = NULL;
+	g_autofree gchar *ref_title = NULL;
 
 	/* get file data */
 	if (!g_file_load_contents (file,
@@ -2553,7 +2534,25 @@ gs_flatpak_file_to_app_ref (GsFlatpak *self,
 		return FALSE;
 	}
 
-#if _FLATPAK_CHECK_VERSION(0,6,10)
+	/* load the file */
+	kf = g_key_file_new ();
+	if (!g_key_file_load_from_data (kf, contents, len, G_KEY_FILE_NONE, error)) {
+		gs_utils_error_convert_gio (error);
+		return FALSE;
+	}
+
+	/* check version */
+	if (g_key_file_has_key (kf, "Flatpak Ref", "Version", NULL)) {
+		guint64 ver = g_key_file_get_uint64 (kf, "Flatpak Ref", "Version", NULL);
+		if (ver != 1) {
+			g_set_error (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "unsupported version %" G_GUINT64_FORMAT, ver);
+			return FALSE;
+		}
+	}
+
 	/* install the remote, but not the app */
 	ref_file_data = g_bytes_new (contents, len);
 	xref = flatpak_installation_install_ref_file (self->installation,
@@ -2564,21 +2563,34 @@ gs_flatpak_file_to_app_ref (GsFlatpak *self,
 		gs_plugin_flatpak_error_convert (error);
 		return FALSE;
 	}
-#else
-	g_set_error_literal (error,
-			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_NOT_SUPPORTED,
-			     "not new enough libflatpak to support flatpakref");
-	return FALSE;
-#endif
 
 	/* load metadata */
 	app = gs_plugin_create_app (self, FLATPAK_REF (xref));
+	gs_app_set_flatpak_file_type (app, "flatpakref");
 	gs_app_set_kind (app, AS_APP_KIND_DESKTOP);
 	gs_app_set_state (app, AS_APP_STATE_AVAILABLE_LOCAL);
 	gs_flatpak_set_metadata (self, app, FLATPAK_REF (xref));
 
-	/* FIXME: perhaps use the data from the flatpakref file as a fallback? */
+	/* use the data from the flatpakref file as a fallback */
+	ref_title = g_key_file_get_string (kf, "Flatpak Ref", "Title", NULL);
+	if (ref_title != NULL)
+		gs_app_set_name (app, GS_APP_QUALITY_NORMAL, ref_title);
+	ref_comment = g_key_file_get_string (kf, "Flatpak Ref", "Comment", NULL);
+	if (ref_comment != NULL)
+		gs_app_set_summary (app, GS_APP_QUALITY_NORMAL, ref_comment);
+	ref_description = g_key_file_get_string (kf, "Flatpak Ref", "Description", NULL);
+	if (ref_description != NULL)
+		gs_app_set_description (app, GS_APP_QUALITY_NORMAL, ref_description);
+	ref_homepage = g_key_file_get_string (kf, "Flatpak Ref", "Homepage", NULL);
+	if (ref_homepage != NULL)
+		gs_app_set_url (app, AS_URL_KIND_HOMEPAGE, ref_homepage);
+	ref_icon = g_key_file_get_string (kf, "Flatpak Ref", "Icon", NULL);
+	if (ref_icon != NULL) {
+		g_autoptr(AsIcon) ic = as_icon_new ();
+		as_icon_set_kind (ic, AS_ICON_KIND_REMOTE);
+		as_icon_set_url (ic, ref_icon);
+		gs_app_add_icon (app, ic);
+	}
 
 	/* set the origin data */
 	remote_name = flatpak_remote_ref_get_remote_name (xref);
@@ -2673,16 +2685,6 @@ gs_flatpak_search (GsFlatpak *self,
 		   GCancellable *cancellable,
 		   GError **error)
 {
-	g_autoptr(GError) error_md = NULL;
-
-	/* if we've never ever run before, get the AppStream data */
-	if (!gs_flatpak_refresh_appstream (self, G_MAXUINT, 0,
-					   cancellable,
-					   &error_md)) {
-		g_warning ("failed to get initial available data: %s",
-			   error_md->message);
-	}
-
 	return gs_appstream_store_search (self->plugin, self->store,
 					  values, list,
 					  cancellable, error);
@@ -2743,6 +2745,12 @@ gs_flatpak_store_app_removed_cb (AsStore *store, AsApp *app, GsFlatpak *self)
 	gs_plugin_cache_remove (self->plugin, as_app_get_unique_id (app));
 }
 
+AsAppScope
+gs_flatpak_get_scope (GsFlatpak *self)
+{
+	return self->scope;
+}
+
 static void
 gs_flatpak_finalize (GObject *object)
 {
@@ -2781,11 +2789,13 @@ gs_flatpak_init (GsFlatpak *self)
 }
 
 GsFlatpak *
-gs_flatpak_new (GsPlugin *plugin, AsAppScope scope)
+gs_flatpak_new (GsPlugin *plugin, FlatpakInstallation *installation)
 {
 	GsFlatpak *self;
 	self = g_object_new (GS_TYPE_FLATPAK, NULL);
-	self->scope = scope;
+	self->installation = g_object_ref (installation);
+	self->scope = flatpak_installation_get_is_user (installation)
+				? AS_APP_SCOPE_USER : AS_APP_SCOPE_SYSTEM;
 	self->plugin = g_object_ref (plugin);
 	return GS_FLATPAK (self);
 }
