@@ -1,6 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2013 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2013-2016 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
@@ -22,49 +21,9 @@
 
 #include "config.h"
 
-#include <glib.h>
-#include <string.h>
 #include <glib-object.h>
-#include <gtk/gtk.h>
 
 #include "gs-markdown.h"
-#include "gs-moduleset.h"
-
-static void
-moduleset_func (void)
-{
-	gboolean ret;
-	gchar **data;
-	GError *error = NULL;
-	g_autoptr(GsModuleset) ms = NULL;
-
-	/* not avaiable in make distcheck */
-	if (!g_file_test ("./moduleset-test.xml", G_FILE_TEST_EXISTS))
-		return;
-
-	ms = gs_moduleset_new ();
-	ret = gs_moduleset_parse_filename (ms, "./moduleset-test.xml", &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-
-	data = gs_moduleset_get_modules (ms,
-					 GS_MODULESET_MODULE_KIND_PACKAGE,
-					 "gnome3",
-					 NULL);
-	g_assert (data != NULL);
-	g_assert_cmpint (g_strv_length (data), ==, 1);
-	g_assert_cmpstr (data[0], ==, "kernel");
-	g_assert_cmpstr (data[1], ==, NULL);
-
-	data = gs_moduleset_get_modules (ms,
-					 GS_MODULESET_MODULE_KIND_APPLICATION,
-					 "gnome3",
-					 NULL);
-	g_assert (data != NULL);
-	g_assert_cmpint (g_strv_length (data), ==, 1);
-	g_assert_cmpstr (data[0], ==, "gnome-shell.desktop");
-	g_assert_cmpstr (data[1], ==, NULL);
-}
 
 static void
 gs_markdown_func (void)
@@ -249,7 +208,6 @@ gs_markdown_func (void)
 int
 main (int argc, char **argv)
 {
-	gtk_init (&argc, &argv);
 	g_test_init (&argc, &argv, NULL);
 	g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
 
@@ -257,7 +215,6 @@ main (int argc, char **argv)
 	g_log_set_fatal_mask (NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
 
 	/* tests go here */
-	g_test_add_func ("/gnome-software/moduleset", moduleset_func);
 	g_test_add_func ("/gnome-software/markdown", gs_markdown_func);
 
 	return g_test_run ();
